@@ -48,6 +48,7 @@
 #include "msg-stats.h"
 #include "timeutils/cache.h"
 #include "multi-line/multi-line-factory.h"
+#include "filterx/filterx-globals.h"
 
 #include <iv.h>
 #include <iv_work.h>
@@ -229,7 +230,6 @@ app_startup(void)
   healthcheck_stats_global_init();
   tzset();
   log_msg_global_init();
-  log_tags_global_init();
   log_source_global_init();
   log_template_global_init();
   value_pairs_global_init();
@@ -242,6 +242,7 @@ app_startup(void)
   msg_stats_init();
   timeutils_global_init();
   multi_line_global_init();
+  filterx_global_init();
 }
 
 void
@@ -269,6 +270,7 @@ app_shutdown(void)
   msg_stats_deinit();
   run_application_hook(AH_SHUTDOWN);
 
+  filterx_global_deinit();
   multi_line_global_deinit();
   main_loop_thread_resource_deinit();
   secret_storage_deinit();
@@ -276,7 +278,6 @@ app_shutdown(void)
   scratch_buffers_global_deinit();
   value_pairs_global_deinit();
   log_template_global_deinit();
-  log_tags_global_deinit();
   log_msg_global_deinit();
 
   afinter_global_deinit();
