@@ -61,13 +61,10 @@ extern int main_debug;
    with care. If you need additional headers, please look for a
    massive list of includes further below. */
 
-#pragma GCC diagnostic ignored "-Wswitch-default"
-#if (defined(__GNUC__) && __GNUC__ >= 6) || (defined(__clang__) && __clang_major__ >= 10)
-#  pragma GCC diagnostic ignored "-Wmisleading-indentation"
-#endif
 /* YYSTYPE and YYLTYPE is defined by the lexer */
 #include "cfg-lexer.h"
 #include "cfg-grammar-internal.h"
+#include "syslog-names.h"
 
 /* uses struct declarations instead of the typedefs to avoid having to
  * include logreader/logwriter/driver.h, which defines the typedefs.  This
@@ -75,7 +72,7 @@ extern int main_debug;
  * themselves reader/writer based */
 
 
-#line 79 "lib/cfg-grammar.h"
+#line 76 "lib/cfg-grammar.h"
 
 /* Token kinds.  */
 #ifndef MAIN_TOKENTYPE
@@ -85,7 +82,7 @@ extern int main_debug;
     MAIN_EMPTY = -2,
     MAIN_EOF = 0,                  /* "end of file"  */
     MAIN_error = 256,              /* error  */
-    MAIN_UNDEF = 10523,            /* "invalid token"  */
+    MAIN_UNDEF = 10531,            /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -106,7 +103,30 @@ extern int main_debug;
     LL_CONTEXT_SERVER_PROTO = 18,  /* LL_CONTEXT_SERVER_PROTO  */
     LL_CONTEXT_OPTIONS = 19,       /* LL_CONTEXT_OPTIONS  */
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
-    LL_CONTEXT_MAX = 21,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
+    LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
+    KW_ASSIGN = 9000,              /* KW_ASSIGN  */
+    KW_OR = 9001,                  /* KW_OR  */
+    KW_AND = 9002,                 /* KW_AND  */
+    KW_STR_EQ = 9003,              /* KW_STR_EQ  */
+    KW_STR_NE = 9004,              /* KW_STR_NE  */
+    KW_TA_EQ = 9005,               /* KW_TA_EQ  */
+    KW_TA_NE = 9006,               /* KW_TA_NE  */
+    KW_TAV_EQ = 9007,              /* KW_TAV_EQ  */
+    KW_TAV_NE = 9008,              /* KW_TAV_NE  */
+    KW_STR_LT = 9009,              /* KW_STR_LT  */
+    KW_STR_LE = 9010,              /* KW_STR_LE  */
+    KW_STR_GE = 9011,              /* KW_STR_GE  */
+    KW_STR_GT = 9012,              /* KW_STR_GT  */
+    KW_TA_LT = 9013,               /* KW_TA_LT  */
+    KW_TA_LE = 9014,               /* KW_TA_LE  */
+    KW_TA_GE = 9015,               /* KW_TA_GE  */
+    KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
+    KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
     KW_PARSER = 10002,             /* KW_PARSER  */
@@ -120,6 +140,7 @@ extern int main_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -141,6 +162,14 @@ extern int main_debug;
     KW_BATCH_LINES = 10087,        /* KW_BATCH_LINES  */
     KW_BATCH_TIMEOUT = 10088,      /* KW_BATCH_TIMEOUT  */
     KW_TRIM_LARGE_MESSAGES = 10089, /* KW_TRIM_LARGE_MESSAGES  */
+    KW_STATS = 10400,              /* KW_STATS  */
+    KW_FREQ = 10401,               /* KW_FREQ  */
+    KW_LEVEL = 10402,              /* KW_LEVEL  */
+    KW_LIFETIME = 10403,           /* KW_LIFETIME  */
+    KW_MAX_DYNAMIC = 10404,        /* KW_MAX_DYNAMIC  */
+    KW_SYSLOG_STATS = 10405,       /* KW_SYSLOG_STATS  */
+    KW_HEALTHCHECK_FREQ = 10406,   /* KW_HEALTHCHECK_FREQ  */
+    KW_WORKER_PARTITION_KEY = 10407, /* KW_WORKER_PARTITION_KEY  */
     KW_CHAIN_HOSTNAMES = 10090,    /* KW_CHAIN_HOSTNAMES  */
     KW_NORMALIZE_HOSTNAMES = 10091, /* KW_NORMALIZE_HOSTNAMES  */
     KW_KEEP_HOSTNAME = 10092,      /* KW_KEEP_HOSTNAME  */
@@ -170,10 +199,10 @@ extern int main_debug;
     KW_HOST_OVERRIDE = 10166,      /* KW_HOST_OVERRIDE  */
     KW_THROTTLE = 10170,           /* KW_THROTTLE  */
     KW_THREADED = 10171,           /* KW_THREADED  */
-    KW_PASS_UNIX_CREDENTIALS = 10231, /* KW_PASS_UNIX_CREDENTIALS  */
-    KW_PERSIST_NAME = 10302,       /* KW_PERSIST_NAME  */
-    KW_READ_OLD_RECORDS = 10304,   /* KW_READ_OLD_RECORDS  */
-    KW_USE_SYSLOGNG_PID = 10305,   /* KW_USE_SYSLOGNG_PID  */
+    KW_PASS_UNIX_CREDENTIALS = 10180, /* KW_PASS_UNIX_CREDENTIALS  */
+    KW_PERSIST_NAME = 10181,       /* KW_PERSIST_NAME  */
+    KW_READ_OLD_RECORDS = 10182,   /* KW_READ_OLD_RECORDS  */
+    KW_USE_SYSLOGNG_PID = 10183,   /* KW_USE_SYSLOGNG_PID  */
     KW_FLAGS = 10190,              /* KW_FLAGS  */
     KW_PAD_SIZE = 10200,           /* KW_PAD_SIZE  */
     KW_TIME_ZONE = 10201,          /* KW_TIME_ZONE  */
@@ -181,10 +210,16 @@ extern int main_debug;
     KW_SEND_TIME_ZONE = 10203,     /* KW_SEND_TIME_ZONE  */
     KW_LOCAL_TIME_ZONE = 10204,    /* KW_LOCAL_TIME_ZONE  */
     KW_FORMAT = 10205,             /* KW_FORMAT  */
-    KW_TRUNCATE_SIZE = 10206,      /* KW_TRUNCATE_SIZE  */
+    KW_MULTI_LINE_MODE = 10206,    /* KW_MULTI_LINE_MODE  */
+    KW_MULTI_LINE_PREFIX = 10207,  /* KW_MULTI_LINE_PREFIX  */
+    KW_MULTI_LINE_GARBAGE = 10208, /* KW_MULTI_LINE_GARBAGE  */
+    KW_TRUNCATE_SIZE = 10209,      /* KW_TRUNCATE_SIZE  */
     KW_TIME_REOPEN = 10210,        /* KW_TIME_REOPEN  */
     KW_TIME_REAP = 10211,          /* KW_TIME_REAP  */
     KW_TIME_SLEEP = 10212,         /* KW_TIME_SLEEP  */
+    KW_PARTITIONS = 10213,         /* KW_PARTITIONS  */
+    KW_PARTITION_KEY = 10214,      /* KW_PARTITION_KEY  */
+    KW_PARALLELIZE = 10215,        /* KW_PARALLELIZE  */
     KW_TMPL_ESCAPE = 10220,        /* KW_TMPL_ESCAPE  */
     KW_OPTIONAL = 10230,           /* KW_OPTIONAL  */
     KW_CREATE_DIRS = 10240,        /* KW_CREATE_DIRS  */
@@ -199,6 +234,7 @@ extern int main_debug;
     KW_TEMPLATE_FUNCTION = 10272,  /* KW_TEMPLATE_FUNCTION  */
     KW_DEFAULT_FACILITY = 10300,   /* KW_DEFAULT_FACILITY  */
     KW_DEFAULT_SEVERITY = 10301,   /* KW_DEFAULT_SEVERITY  */
+    KW_SDATA_PREFIX = 10302,       /* KW_SDATA_PREFIX  */
     KW_PORT = 10323,               /* KW_PORT  */
     KW_USE_TIME_RECVD = 10340,     /* KW_USE_TIME_RECVD  */
     KW_FACILITY = 10350,           /* KW_FACILITY  */
@@ -214,6 +250,7 @@ extern int main_debug;
     KW_VALUE = 10372,              /* KW_VALUE  */
     KW_YES = 10380,                /* KW_YES  */
     KW_NO = 10381,                 /* KW_NO  */
+    KW_AUTO = 10382,               /* KW_AUTO  */
     KW_IFDEF = 10410,              /* KW_IFDEF  */
     KW_ENDIF = 10411,              /* KW_ENDIF  */
     LL_DOTDOT = 10420,             /* LL_DOTDOT  */
@@ -229,6 +266,8 @@ extern int main_debug;
     LL_TOKEN = 10434,              /* LL_TOKEN  */
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
+    LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -240,9 +279,13 @@ extern int main_debug;
     KW_ADD_PREFIX = 10509,         /* KW_ADD_PREFIX  */
     KW_REPLACE_PREFIX = 10510,     /* KW_REPLACE_PREFIX  */
     KW_CAST = 10511,               /* KW_CAST  */
+    KW_UPPER = 10512,              /* KW_UPPER  */
+    KW_LOWER = 10513,              /* KW_LOWER  */
+    KW_INCLUDE_BYTES = 10514,      /* KW_INCLUDE_BYTES  */
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
-    KW_FETCH_NO_DATA_DELAY = 10522 /* KW_FETCH_NO_DATA_DELAY  */
+    KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
+    KW_LABELS = 10530              /* KW_LABELS  */
   };
   typedef enum main_tokentype main_token_kind_t;
 #endif
@@ -250,7 +293,7 @@ extern int main_debug;
 #define MAIN_EMPTY -2
 #define MAIN_EOF 0
 #define MAIN_error 256
-#define MAIN_UNDEF 10523
+#define MAIN_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -271,7 +314,30 @@ extern int main_debug;
 #define LL_CONTEXT_SERVER_PROTO 18
 #define LL_CONTEXT_OPTIONS 19
 #define LL_CONTEXT_CONFIG 20
-#define LL_CONTEXT_MAX 21
+#define LL_CONTEXT_TEMPLATE_REF 21
+#define LL_CONTEXT_FILTERX 22
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
+#define KW_ASSIGN 9000
+#define KW_OR 9001
+#define KW_AND 9002
+#define KW_STR_EQ 9003
+#define KW_STR_NE 9004
+#define KW_TA_EQ 9005
+#define KW_TA_NE 9006
+#define KW_TAV_EQ 9007
+#define KW_TAV_NE 9008
+#define KW_STR_LT 9009
+#define KW_STR_LE 9010
+#define KW_STR_GE 9011
+#define KW_STR_GT 9012
+#define KW_TA_LT 9013
+#define KW_TA_LE 9014
+#define KW_TA_GE 9015
+#define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
+#define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
 #define KW_PARSER 10002
@@ -285,6 +351,7 @@ extern int main_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -306,6 +373,14 @@ extern int main_debug;
 #define KW_BATCH_LINES 10087
 #define KW_BATCH_TIMEOUT 10088
 #define KW_TRIM_LARGE_MESSAGES 10089
+#define KW_STATS 10400
+#define KW_FREQ 10401
+#define KW_LEVEL 10402
+#define KW_LIFETIME 10403
+#define KW_MAX_DYNAMIC 10404
+#define KW_SYSLOG_STATS 10405
+#define KW_HEALTHCHECK_FREQ 10406
+#define KW_WORKER_PARTITION_KEY 10407
 #define KW_CHAIN_HOSTNAMES 10090
 #define KW_NORMALIZE_HOSTNAMES 10091
 #define KW_KEEP_HOSTNAME 10092
@@ -335,10 +410,10 @@ extern int main_debug;
 #define KW_HOST_OVERRIDE 10166
 #define KW_THROTTLE 10170
 #define KW_THREADED 10171
-#define KW_PASS_UNIX_CREDENTIALS 10231
-#define KW_PERSIST_NAME 10302
-#define KW_READ_OLD_RECORDS 10304
-#define KW_USE_SYSLOGNG_PID 10305
+#define KW_PASS_UNIX_CREDENTIALS 10180
+#define KW_PERSIST_NAME 10181
+#define KW_READ_OLD_RECORDS 10182
+#define KW_USE_SYSLOGNG_PID 10183
 #define KW_FLAGS 10190
 #define KW_PAD_SIZE 10200
 #define KW_TIME_ZONE 10201
@@ -346,10 +421,16 @@ extern int main_debug;
 #define KW_SEND_TIME_ZONE 10203
 #define KW_LOCAL_TIME_ZONE 10204
 #define KW_FORMAT 10205
-#define KW_TRUNCATE_SIZE 10206
+#define KW_MULTI_LINE_MODE 10206
+#define KW_MULTI_LINE_PREFIX 10207
+#define KW_MULTI_LINE_GARBAGE 10208
+#define KW_TRUNCATE_SIZE 10209
 #define KW_TIME_REOPEN 10210
 #define KW_TIME_REAP 10211
 #define KW_TIME_SLEEP 10212
+#define KW_PARTITIONS 10213
+#define KW_PARTITION_KEY 10214
+#define KW_PARALLELIZE 10215
 #define KW_TMPL_ESCAPE 10220
 #define KW_OPTIONAL 10230
 #define KW_CREATE_DIRS 10240
@@ -364,6 +445,7 @@ extern int main_debug;
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
 #define KW_DEFAULT_SEVERITY 10301
+#define KW_SDATA_PREFIX 10302
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
@@ -379,6 +461,7 @@ extern int main_debug;
 #define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
+#define KW_AUTO 10382
 #define KW_IFDEF 10410
 #define KW_ENDIF 10411
 #define LL_DOTDOT 10420
@@ -394,6 +477,8 @@ extern int main_debug;
 #define LL_TOKEN 10434
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
+#define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -405,9 +490,13 @@ extern int main_debug;
 #define KW_ADD_PREFIX 10509
 #define KW_REPLACE_PREFIX 10510
 #define KW_CAST 10511
+#define KW_UPPER 10512
+#define KW_LOWER 10513
+#define KW_INCLUDE_BYTES 10514
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
+#define KW_LABELS 10530
 
 /* Value type.  */
 #if ! defined MAIN_STYPE && ! defined MAIN_STYPE_IS_DECLARED
