@@ -628,6 +628,8 @@ cfg_lexer_include_file_glob_at(CfgLexer *self, CfgIncludeLevel *level, const gch
 
   r = glob(pattern, GLOB_NOMAGIC, _cfg_lexer_glob_err, &globbuf);
 
+  if (r == 0 && globbuf.gl_pathc == 0)
+    r = GLOB_NOMATCH;
   if (r != 0)
     {
       globfree(&globbuf);
@@ -1256,6 +1258,8 @@ static const gchar *lexer_contexts[] =
   [LL_CONTEXT_CONFIG] = "config",
   [LL_CONTEXT_TEMPLATE_REF] = "template-ref",
   [LL_CONTEXT_FILTERX] = "filterx",
+  [LL_CONTEXT_FILTERX_FUNC] = "filterx-func",
+  [LL_CONTEXT_FILTERX_ENUM] = "filterx-enum",
 };
 
 gint
