@@ -40,6 +40,8 @@
 #include "host-id.h"
 #include "ack-tracker/ack_tracker.h"
 #include "apphook.h"
+#include "scratch-buffers.h"
+#include "str-format.h"
 
 #include <glib/gprintf.h>
 #include <sys/types.h>
@@ -585,11 +587,12 @@ log_msg_rename_value(LogMessage *self, NVHandle from, NVHandle to)
     return;
 
   gssize value_len = 0;
-  const gchar *value = log_msg_get_value_if_set(self, from, &value_len);
+  LogMessageValueType type;
+  const gchar *value = log_msg_get_value_if_set_with_type(self, from, &value_len, &type);
   if (!value)
     return;
 
-  log_msg_set_value(self, to, value, value_len);
+  log_msg_set_value_with_type(self, to, value, value_len, type);
   log_msg_unset_value(self, from);
 }
 
@@ -1213,11 +1216,11 @@ log_msg_append_format_sdata(const LogMessage *self, GString *result,  guint32 se
          if seq_num isn't 0 */
       if (!has_seq_num && seq_num!=0 && strncmp(sdata_elem, "meta.", 5) == 0)
         {
-          gchar sequence_id[16];
-          g_snprintf(sequence_id, sizeof(sequence_id), "%d", seq_num);
+          GString *sequence_id = scratch_buffers_alloc();
+          format_uint64_padded(sequence_id, 0, 0, 10, seq_num);
           g_string_append_c(result, ' ');
           g_string_append_len(result, "sequenceId=\"", 12);
-          g_string_append_len(result, sequence_id, strlen(sequence_id));
+          g_string_append_len(result, sequence_id->str, sequence_id->len);
           g_string_append_c(result, '"');
           has_seq_num = TRUE;
         }
@@ -1243,11 +1246,12 @@ log_msg_append_format_sdata(const LogMessage *self, GString *result,  guint32 se
   */
   if (!has_seq_num && seq_num!=0)
     {
-      gchar sequence_id[16];
-      g_snprintf(sequence_id, sizeof(sequence_id), "%d", seq_num);
+      GString *sequence_id = scratch_buffers_alloc();
+      format_uint64_padded(sequence_id, 0, 0, 10, seq_num);
+
       g_string_append_c(result, '[');
       g_string_append_len(result, "meta sequenceId=\"", 17);
-      g_string_append_len(result, sequence_id, strlen(sequence_id));
+      g_string_append_len(result, sequence_id->str, sequence_id->len);
       g_string_append_len(result, "\"]", 2);
     }
 }
@@ -1436,7 +1440,7 @@ _merge_value(NVHandle handle,
 {
   LogMessage *msg = (LogMessage *) user_data;
 
-  if (!nv_table_is_value_set(msg->payload, handle))
+  if (!log_msg_is_value_set(msg, handle))
     log_msg_set_value_with_type(msg, handle, value, value_len, type);
   return FALSE;
 }
@@ -1802,7 +1806,7 @@ log_msg_ack(LogMessage *self, const LogPathOptions *path_options, AckType ack_ty
  * to send to further consuming pipes.
  */
 const LogPathOptions *
-log_msg_break_ack(LogMessage *msg, const LogPathOptions *path_options, LogPathOptions *local_options)
+log_msg_break_ack(LogMessage *msg, const LogPathOptions *path_options, LogPathOptions *local_path_options)
 {
   /* NOTE: in case the user requested flow control, we can't break the
    * ACK chain, as that would lead to early acks, that would cause
@@ -1812,10 +1816,10 @@ log_msg_break_ack(LogMessage *msg, const LogPathOptions *path_options, LogPathOp
 
   log_msg_ack(msg, path_options, AT_PROCESSED);
 
-  *local_options = *path_options;
-  local_options->ack_needed = FALSE;
+  log_path_options_chain(local_path_options, path_options);
+  local_path_options->ack_needed = FALSE;
 
-  return local_options;
+  return local_path_options;
 }
 
 
@@ -1991,6 +1995,20 @@ log_msg_refcache_stop(void)
   logmsg_current = NULL;
 }
 
+void
+log_msg_tags_init(void)
+{
+  log_tags_register_predefined_tag("message.utf8_sanitized", LM_T_MSG_UTF8_SANITIZED);
+  log_tags_register_predefined_tag("message.parse_error", LM_T_MSG_PARSE_ERROR);
+
+  log_tags_register_predefined_tag("syslog.missing_pri", LM_T_SYSLOG_MISSING_PRI);
+  log_tags_register_predefined_tag("syslog.missing_timestamp", LM_T_SYSLOG_MISSING_TIMESTAMP);
+  log_tags_register_predefined_tag("syslog.invalid_hostname", LM_T_SYSLOG_INVALID_HOSTNAME);
+  log_tags_register_predefined_tag("syslog.unexpected_framing", LM_T_SYSLOG_UNEXPECTED_FRAMING);
+  log_tags_register_predefined_tag("syslog.rfc3164_missing_header", LM_T_SYSLOG_RFC3164_MISSING_HEADER);
+  log_tags_register_predefined_tag("syslog.rfc5424_unquoted_sdata_value", LM_T_SYSLOG_RFC5424_UNQUOTED_SDATA_VALUE);
+}
+
 void
 log_msg_registry_init(void)
 {
@@ -2004,6 +2022,7 @@ log_msg_registry_init(void)
 
   nv_registry_add_predefined(logmsg_registry, LM_V_RAWMSG, "RAWMSG");
   nv_registry_add_predefined(logmsg_registry, LM_V_TRANSPORT, "TRANSPORT");
+  nv_registry_add_predefined(logmsg_registry, LM_V_MSGFORMAT, "MSGFORMAT");
   nv_registry_add_predefined(logmsg_registry, LM_V_FILE_NAME, "FILE_NAME");
 
   nv_registry_assert_next_handle(logmsg_registry, LM_V_PREDEFINED_MAX);
@@ -2067,6 +2086,8 @@ void
 log_msg_global_init(void)
 {
   log_msg_registry_init();
+  log_tags_global_init();
+  log_msg_tags_init();
 
   /* NOTE: we always initialize counters as they are on stats-level(0),
    * however we need to defer that as the stats subsystem may not be
@@ -2084,6 +2105,7 @@ log_msg_get_handle_name(NVHandle handle, gssize *length)
 void
 log_msg_global_deinit(void)
 {
+  log_tags_global_deinit();
   log_msg_registry_deinit();
 }
 
