@@ -57,6 +57,13 @@ _arcs(LogPipe *self)
     return NULL;
 }
 
+void
+log_pipe_clone_method(LogPipe *dst, const LogPipe *src)
+{
+  log_pipe_set_persist_name(dst, src->persist_name);
+  log_pipe_set_options(dst, &src->options);
+}
+
 void
 log_pipe_init_instance(LogPipe *self, GlobalConfig *cfg)
 {
@@ -116,7 +123,7 @@ _free(LogPipe *self)
   g_free(self);
 }
 
-void
+gboolean
 log_pipe_unref(LogPipe *self)
 {
   g_assert(!self || g_atomic_counter_get(&self->ref_cnt));
@@ -124,7 +131,10 @@ log_pipe_unref(LogPipe *self)
   if (self && (g_atomic_counter_dec_and_test(&self->ref_cnt)))
     {
       _free(self);
+      return TRUE;
     }
+
+  return FALSE;
 }
 
 void
@@ -147,6 +157,24 @@ log_pipe_get_persist_name(const LogPipe *self)
          : self->persist_name;
 }
 
+void
+log_pipe_set_options(LogPipe *self, const LogPipeOptions *options)
+{
+  self->options = *options;
+}
+
+void
+log_pipe_set_internal(LogPipe *self, gboolean internal)
+{
+  self->options.internal = internal;
+}
+
+gboolean
+log_pipe_is_internal(const LogPipe *self)
+{
+  return self->options.internal;
+}
+
 void
 log_pipe_add_info(LogPipe *self, const gchar *info)
 {
