@@ -69,7 +69,7 @@ extern int rewrite_expr_debug;
     REWRITE_EXPR_EMPTY = -2,
     REWRITE_EXPR_EOF = 0,          /* "end of file"  */
     REWRITE_EXPR_error = 256,      /* error  */
-    REWRITE_EXPR_UNDEF = 10523,    /* "invalid token"  */
+    REWRITE_EXPR_UNDEF = 10531,    /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -92,7 +92,9 @@ extern int rewrite_expr_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -110,6 +112,7 @@ extern int rewrite_expr_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -124,6 +127,7 @@ extern int rewrite_expr_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -250,6 +254,7 @@ extern int rewrite_expr_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -267,20 +272,21 @@ extern int rewrite_expr_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_SET_TAG = 10524,            /* KW_SET_TAG  */
-    KW_CLEAR_TAG = 10525,          /* KW_CLEAR_TAG  */
-    KW_GROUP_SET = 10526,          /* KW_GROUP_SET  */
-    KW_GROUP_UNSET = 10527,        /* KW_GROUP_UNSET  */
-    KW_SET = 10528,                /* KW_SET  */
-    KW_UNSET = 10529,              /* KW_UNSET  */
-    KW_RENAME = 10530,             /* KW_RENAME  */
-    KW_SUBST = 10531,              /* KW_SUBST  */
-    KW_VALUES = 10532,             /* KW_VALUES  */
-    KW_SET_SEVERITY = 10533,       /* KW_SET_SEVERITY  */
-    KW_SET_FACILITY = 10534,       /* KW_SET_FACILITY  */
-    KW_SET_PRI = 10535,            /* KW_SET_PRI  */
-    KW_SET_MATCHES = 10536,        /* KW_SET_MATCHES  */
-    KW_UNSET_MATCHES = 10537       /* KW_UNSET_MATCHES  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_SET_TAG = 10532,            /* KW_SET_TAG  */
+    KW_CLEAR_TAG = 10533,          /* KW_CLEAR_TAG  */
+    KW_GROUP_SET = 10534,          /* KW_GROUP_SET  */
+    KW_GROUP_UNSET = 10535,        /* KW_GROUP_UNSET  */
+    KW_SET = 10536,                /* KW_SET  */
+    KW_UNSET = 10537,              /* KW_UNSET  */
+    KW_RENAME = 10538,             /* KW_RENAME  */
+    KW_SUBST = 10539,              /* KW_SUBST  */
+    KW_VALUES = 10540,             /* KW_VALUES  */
+    KW_SET_SEVERITY = 10541,       /* KW_SET_SEVERITY  */
+    KW_SET_FACILITY = 10542,       /* KW_SET_FACILITY  */
+    KW_SET_PRI = 10543,            /* KW_SET_PRI  */
+    KW_SET_MATCHES = 10544,        /* KW_SET_MATCHES  */
+    KW_UNSET_MATCHES = 10545       /* KW_UNSET_MATCHES  */
   };
   typedef enum rewrite_expr_tokentype rewrite_expr_token_kind_t;
 #endif
@@ -288,7 +294,7 @@ extern int rewrite_expr_debug;
 #define REWRITE_EXPR_EMPTY -2
 #define REWRITE_EXPR_EOF 0
 #define REWRITE_EXPR_error 256
-#define REWRITE_EXPR_UNDEF 10523
+#define REWRITE_EXPR_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -311,7 +317,9 @@ extern int rewrite_expr_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -329,6 +337,7 @@ extern int rewrite_expr_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -343,6 +352,7 @@ extern int rewrite_expr_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -469,6 +479,7 @@ extern int rewrite_expr_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -486,20 +497,21 @@ extern int rewrite_expr_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_SET_TAG 10524
-#define KW_CLEAR_TAG 10525
-#define KW_GROUP_SET 10526
-#define KW_GROUP_UNSET 10527
-#define KW_SET 10528
-#define KW_UNSET 10529
-#define KW_RENAME 10530
-#define KW_SUBST 10531
-#define KW_VALUES 10532
-#define KW_SET_SEVERITY 10533
-#define KW_SET_FACILITY 10534
-#define KW_SET_PRI 10535
-#define KW_SET_MATCHES 10536
-#define KW_UNSET_MATCHES 10537
+#define KW_LABELS 10530
+#define KW_SET_TAG 10532
+#define KW_CLEAR_TAG 10533
+#define KW_GROUP_SET 10534
+#define KW_GROUP_UNSET 10535
+#define KW_SET 10536
+#define KW_UNSET 10537
+#define KW_RENAME 10538
+#define KW_SUBST 10539
+#define KW_VALUES 10540
+#define KW_SET_SEVERITY 10541
+#define KW_SET_FACILITY 10542
+#define KW_SET_PRI 10543
+#define KW_SET_MATCHES 10544
+#define KW_UNSET_MATCHES 10545
 
 /* Value type.  */
 #if ! defined REWRITE_EXPR_STYPE && ! defined REWRITE_EXPR_STYPE_IS_DECLARED
