@@ -81,15 +81,17 @@
  *  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-#include <ctype.h>
-#include <stdint.h>
-#include <string.h>
 
 #include "timeutils/wallclocktime.h"
 #include "timeutils/unixtime.h"
 #include "timeutils/cache.h"
 #include "timeutils/misc.h"
 
+#include <ctype.h>
+#include <stdint.h>
+#include <string.h>
+
+
 void
 wall_clock_time_unset(WallClockTime *self)
 {
@@ -268,6 +270,12 @@ static const int start_of_month[2][13] =
   { 0, 31, 60, 91, 121, 152, 182, 213, 244, 274, 305, 335, 366 }
 };
 
+static inline gboolean
+_is_str_empty(const gchar *str)
+{
+  return !str || strcmp(str, "") == 0;
+}
+
 gchar *
 wall_clock_time_strptime(WallClockTime *wct, const gchar *format, const gchar *input)
 {
@@ -276,6 +284,8 @@ wall_clock_time_strptime(WallClockTime *wct, const gchar *format, const gchar *i
   int alt_format, i, split_year = 0, neg = 0, state = 0,
                      day_offset = -1, week_offset = 0, offs, mandatory;
   const char *new_fmt;
+  const char *const *system_tznames;
+  int system_tznames_len;
 
   bp = (const unsigned char *)input;
 
@@ -670,14 +680,14 @@ recurse:
                   bp = ep;
                   continue;
                 }
-              ep = find_string(bp, &i, (const char *const *)tzname, NULL, 2);
+              system_tznames = cached_get_system_tznames();
+              system_tznames_len = _is_str_empty(system_tznames[1]) ? 1 : 2;
+              ep = find_string(bp, &i, system_tznames, NULL, system_tznames_len);
               if (ep != NULL)
                 {
                   wct->tm.tm_isdst = i;
-#ifdef SYSLOG_NG_HAVE_TIMEZONE
-                  wct->wct_gmtoff = -(timezone);
-#endif
-                  wct->wct_zone = tzname[i];
+                  wct->wct_gmtoff = -cached_get_system_tzofs() + wct->tm.tm_isdst*3600;
+                  wct->wct_zone = system_tznames[i];
                   bp = ep;
                   continue;
                 }
@@ -698,7 +708,11 @@ recurse:
                   bp++;
                   continue;
                 }
-              return NULL;
+              if (mandatory)
+                return NULL;
+
+              bp = zname;
+              continue;
             }
           offs = 0;
           for (i = 0; i < 4; )
@@ -719,7 +733,7 @@ recurse:
           switch (i)
             {
             case 2:
-              offs *= 60;
+              offs *= 3600;
               break;
             case 4:
               i = offs % 100;
@@ -860,15 +874,60 @@ wall_clock_time_guess_missing_year(WallClockTime *self)
 {
   if (self->wct_year == -1)
     {
-      time_t now;
+      time_t now = get_cached_realtime_sec();
       struct tm tm;
 
-      now = cached_g_current_time_sec();
       cached_localtime(&now, &tm);
       self->wct_year = determine_year_for_month(self->wct_mon, &tm);
     }
 }
 
+void
+wall_clock_time_guess_missing_fields(WallClockTime *self)
+{
+  /*
+   * The missing cases for date can be divided into three types:
+   * 1) missing all fileds -> use current date
+   * 2) only miss year -> guess year based on current year and month (current
+   * year, last year or next year)
+   * 3) the rest of the cases don't make much sense, so zero initialization of
+   * the missing field makes sense. And the year is initializeed to the current
+   *  one.
+   */
+  time_t now = get_cached_realtime_sec();
+  struct tm tm;
+
+  cached_localtime(&now, &tm);
+
+  if (self->wct_year == -1 && self->wct_mon == -1 && self->wct_mday == -1)
+    {
+      self->wct_year = tm.tm_year;
+      self->wct_mon = tm.tm_mon;
+      self->wct_mday = tm.tm_mday;
+    }
+  else if (self->wct_year == -1 && self->wct_mon != -1 && self->wct_mday != -1)
+    {
+      self->wct_year = determine_year_for_month(self->wct_mon, &tm);
+    }
+  else
+    {
+      if (self->wct_year == -1)
+        self->wct_year = tm.tm_year;
+      if (self->wct_mon == -1)
+        self->wct_mon = 0;
+      if (self->wct_mday == -1)
+        self->wct_mday = 1;  // day of the month - [1, 31]
+    }
+
+  if (self->wct_hour == -1)
+    self->wct_hour = 0;
+  if (self->wct_min == -1)
+    self->wct_min = 0;
+  if (self->wct_sec == -1)
+    self->wct_sec = 0;
+}
+
+
 /*
  * Calculate the week day of the first day of a year. Valid for
  * the Gregorian calendar, which began Sept 14, 1752 in the UK
