@@ -69,7 +69,7 @@ extern int afamqp_debug;
     AFAMQP_EMPTY = -2,
     AFAMQP_EOF = 0,                /* "end of file"  */
     AFAMQP_error = 256,            /* error  */
-    AFAMQP_UNDEF = 10523,          /* "invalid token"  */
+    AFAMQP_UNDEF = 10531,          /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -92,7 +92,9 @@ extern int afamqp_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -110,6 +112,7 @@ extern int afamqp_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -124,6 +127,7 @@ extern int afamqp_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -250,6 +254,7 @@ extern int afamqp_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -267,25 +272,26 @@ extern int afamqp_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_AMQP = 10524,               /* KW_AMQP  */
-    KW_EXCHANGE = 10525,           /* KW_EXCHANGE  */
-    KW_EXCHANGE_DECLARE = 10526,   /* KW_EXCHANGE_DECLARE  */
-    KW_EXCHANGE_TYPE = 10527,      /* KW_EXCHANGE_TYPE  */
-    KW_PERSISTENT = 10528,         /* KW_PERSISTENT  */
-    KW_VHOST = 10529,              /* KW_VHOST  */
-    KW_ROUTING_KEY = 10530,        /* KW_ROUTING_KEY  */
-    KW_BODY = 10531,               /* KW_BODY  */
-    KW_AUTH_METHOD = 10532,        /* KW_AUTH_METHOD  */
-    KW_PASSWORD = 10533,           /* KW_PASSWORD  */
-    KW_USERNAME = 10534,           /* KW_USERNAME  */
-    KW_MAX_CHANNEL = 10535,        /* KW_MAX_CHANNEL  */
-    KW_FRAME_SIZE = 10536,         /* KW_FRAME_SIZE  */
-    KW_HEARTBEAT = 10537,          /* KW_HEARTBEAT  */
-    KW_CA_FILE = 10538,            /* KW_CA_FILE  */
-    KW_KEY_FILE = 10539,           /* KW_KEY_FILE  */
-    KW_CERT_FILE = 10540,          /* KW_CERT_FILE  */
-    KW_PEER_VERIFY = 10541,        /* KW_PEER_VERIFY  */
-    KW_TLS = 10542                 /* KW_TLS  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_AMQP = 10532,               /* KW_AMQP  */
+    KW_EXCHANGE = 10533,           /* KW_EXCHANGE  */
+    KW_EXCHANGE_DECLARE = 10534,   /* KW_EXCHANGE_DECLARE  */
+    KW_EXCHANGE_TYPE = 10535,      /* KW_EXCHANGE_TYPE  */
+    KW_PERSISTENT = 10536,         /* KW_PERSISTENT  */
+    KW_VHOST = 10537,              /* KW_VHOST  */
+    KW_ROUTING_KEY = 10538,        /* KW_ROUTING_KEY  */
+    KW_BODY = 10539,               /* KW_BODY  */
+    KW_AUTH_METHOD = 10540,        /* KW_AUTH_METHOD  */
+    KW_PASSWORD = 10541,           /* KW_PASSWORD  */
+    KW_USERNAME = 10542,           /* KW_USERNAME  */
+    KW_MAX_CHANNEL = 10543,        /* KW_MAX_CHANNEL  */
+    KW_FRAME_SIZE = 10544,         /* KW_FRAME_SIZE  */
+    KW_HEARTBEAT = 10545,          /* KW_HEARTBEAT  */
+    KW_CA_FILE = 10546,            /* KW_CA_FILE  */
+    KW_KEY_FILE = 10547,           /* KW_KEY_FILE  */
+    KW_CERT_FILE = 10548,          /* KW_CERT_FILE  */
+    KW_PEER_VERIFY = 10549,        /* KW_PEER_VERIFY  */
+    KW_TLS = 10550                 /* KW_TLS  */
   };
   typedef enum afamqp_tokentype afamqp_token_kind_t;
 #endif
@@ -293,7 +299,7 @@ extern int afamqp_debug;
 #define AFAMQP_EMPTY -2
 #define AFAMQP_EOF 0
 #define AFAMQP_error 256
-#define AFAMQP_UNDEF 10523
+#define AFAMQP_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -316,7 +322,9 @@ extern int afamqp_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -334,6 +342,7 @@ extern int afamqp_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -348,6 +357,7 @@ extern int afamqp_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -474,6 +484,7 @@ extern int afamqp_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -491,25 +502,26 @@ extern int afamqp_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_AMQP 10524
-#define KW_EXCHANGE 10525
-#define KW_EXCHANGE_DECLARE 10526
-#define KW_EXCHANGE_TYPE 10527
-#define KW_PERSISTENT 10528
-#define KW_VHOST 10529
-#define KW_ROUTING_KEY 10530
-#define KW_BODY 10531
-#define KW_AUTH_METHOD 10532
-#define KW_PASSWORD 10533
-#define KW_USERNAME 10534
-#define KW_MAX_CHANNEL 10535
-#define KW_FRAME_SIZE 10536
-#define KW_HEARTBEAT 10537
-#define KW_CA_FILE 10538
-#define KW_KEY_FILE 10539
-#define KW_CERT_FILE 10540
-#define KW_PEER_VERIFY 10541
-#define KW_TLS 10542
+#define KW_LABELS 10530
+#define KW_AMQP 10532
+#define KW_EXCHANGE 10533
+#define KW_EXCHANGE_DECLARE 10534
+#define KW_EXCHANGE_TYPE 10535
+#define KW_PERSISTENT 10536
+#define KW_VHOST 10537
+#define KW_ROUTING_KEY 10538
+#define KW_BODY 10539
+#define KW_AUTH_METHOD 10540
+#define KW_PASSWORD 10541
+#define KW_USERNAME 10542
+#define KW_MAX_CHANNEL 10543
+#define KW_FRAME_SIZE 10544
+#define KW_HEARTBEAT 10545
+#define KW_CA_FILE 10546
+#define KW_KEY_FILE 10547
+#define KW_CERT_FILE 10548
+#define KW_PEER_VERIFY 10549
+#define KW_TLS 10550
 
 /* Value type.  */
 #if ! defined AFAMQP_STYPE && ! defined AFAMQP_STYPE_IS_DECLARED
