@@ -37,6 +37,13 @@
 
 #include <iv.h>
 
+void
+affile_sd_set_transport_name(AFFileSourceDriver *self, const gchar *transport_name)
+{
+  g_free(self->transport_name);
+  self->transport_name = g_strdup(transport_name);
+  self->transport_name_len = strlen(transport_name);
+}
 
 static gboolean
 _is_linux_proc_kmsg(const gchar *filename)
@@ -78,22 +85,12 @@ affile_sd_format_persist_name(const LogPipe *s)
 static void
 affile_sd_queue(LogPipe *s, LogMessage *msg, const LogPathOptions *path_options)
 {
+  AFFileSourceDriver *self = (AFFileSourceDriver *) s;
+
+  log_msg_set_value(msg, LM_V_TRANSPORT, self->transport_name, self->transport_name_len);
   log_src_driver_queue_method(s, msg, path_options);
 }
 
-static gboolean
-_are_multi_line_settings_invalid(AFFileSourceDriver *self)
-{
-  LogProtoMultiLineServerOptions *multi_line_options =
-    (LogProtoMultiLineServerOptions *) &self->file_reader_options.reader_options.proto_options;
-
-  gboolean is_garbage_mode = multi_line_options->mode == MLM_PREFIX_GARBAGE;
-  gboolean is_suffix_mode = multi_line_options->mode == MLM_PREFIX_SUFFIX;
-
-  return (!is_garbage_mode && !is_suffix_mode) && (multi_line_options->prefix
-                                                   || multi_line_options->garbage);
-}
-
 static gboolean
 affile_sd_init(LogPipe *s)
 {
@@ -103,20 +100,16 @@ affile_sd_init(LogPipe *s)
   if (!log_src_driver_init_method(s))
     return FALSE;
 
-  file_reader_options_init(&self->file_reader_options, cfg, self->super.super.group);
+  if (!file_reader_options_init(&self->file_reader_options, cfg, self->super.super.group))
+    return FALSE;
+
   file_opener_options_init(&self->file_opener_options, cfg);
 
   file_opener_set_options(self->file_opener, &self->file_opener_options);
   self->file_reader = file_reader_new(self->filename->str, &self->file_reader_options,
                                       self->file_opener,
                                       &self->super, cfg);
-
-  if (_are_multi_line_settings_invalid(self))
-    {
-      msg_error("multi-line-prefix() and/or multi-line-garbage() specified but multi-line-mode() is not regexp based "
-                "(prefix-garbage or prefix-suffix), please set multi-line-mode() properly");
-      return FALSE;
-    }
+  log_pipe_set_options(&self->file_reader->super, &self->super.super.super.options);
 
   log_pipe_append(&self->file_reader->super, &self->super.super.super);
   return log_pipe_init(&self->file_reader->super);
@@ -140,6 +133,7 @@ affile_sd_free(LogPipe *s)
 {
   AFFileSourceDriver *self = (AFFileSourceDriver *) s;
 
+  g_free(self->transport_name);
   file_opener_free(self->file_opener);
   log_pipe_unref(&self->file_reader->super);
   g_string_free(self->filename, TRUE);
@@ -177,24 +171,36 @@ affile_sd_new(gchar *filename, GlobalConfig *cfg)
 
   self->file_reader_options.reader_options.super.stats_source = stats_register_type("file");
 
-  if (_is_device_node(filename) || _is_linux_proc_kmsg(filename))
-    self->file_reader_options.follow_freq = 0;
-  else
-    self->file_reader_options.follow_freq = 1000;
-
-  if (self->file_reader_options.follow_freq > 0)
-    self->file_opener = file_opener_for_regular_source_files_new();
-  else if (_is_linux_proc_kmsg(self->filename->str))
+  if (_is_device_node(filename))
     {
+      self->file_reader_options.follow_freq = 0;
+      if (_is_linux_dev_kmsg(self->filename->str))
+        {
+          self->file_opener = file_opener_for_devkmsg_new();
+          affile_sd_set_transport_name(self, "local+devkmsg");
+        }
+      else
+        {
+          self->file_opener = file_opener_for_regular_source_files_new();
+          affile_sd_set_transport_name(self, "local+device");
+        }
+    }
+  else if (_is_linux_proc_kmsg(filename))
+    {
+      affile_sd_set_transport_name(self, "local+prockmsg");
+      self->file_reader_options.follow_freq = 0;
       self->file_opener_options.needs_privileges = TRUE;
       self->file_opener = file_opener_for_prockmsg_new();
     }
-  else if (_is_linux_dev_kmsg(self->filename->str))
-    self->file_opener = file_opener_for_devkmsg_new();
   else
-    self->file_opener = file_opener_for_regular_source_files_new();
+    {
+      affile_sd_set_transport_name(self, "local+file");
+      self->file_reader_options.follow_freq = 1000;
+      self->file_opener = file_opener_for_regular_source_files_new();
+    }
 
   self->file_reader_options.restore_state = self->file_reader_options.follow_freq > 0;
   file_opener_options_defaults_dont_change_permissions(&self->file_opener_options);
+  self->file_opener_options.create_dirs = FALSE;
   return &self->super.super;
 }
