@@ -258,6 +258,13 @@ afprogram_sd_exit(pid_t pid, int status, gpointer s)
     }
 }
 
+static void
+afprogram_sd_queue(LogPipe *s, LogMessage *msg, const LogPathOptions *path_options)
+{
+  log_msg_set_value_to_string(msg, LM_V_TRANSPORT, "local+program");
+  log_src_driver_queue_method(s, msg, path_options);
+}
+
 static gboolean
 afprogram_sd_init(LogPipe *s)
 {
@@ -370,6 +377,7 @@ afprogram_sd_new(gchar *cmdline, GlobalConfig *cfg)
   self->super.super.super.deinit = afprogram_sd_deinit;
   self->super.super.super.free_fn = afprogram_sd_free;
   self->super.super.super.notify = afprogram_sd_notify;
+  self->super.super.super.queue = afprogram_sd_queue;
   self->process_info.cmdline = g_string_new(cmdline);
   afprogram_set_inherit_environment(&self->process_info, TRUE);
   log_reader_options_defaults(&self->reader_options);
