@@ -150,7 +150,9 @@ extern int afsocket_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -168,6 +170,7 @@ extern int afsocket_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -182,6 +185,7 @@ extern int afsocket_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -308,6 +312,7 @@ extern int afsocket_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -324,7 +329,8 @@ extern int afsocket_debug;
     KW_INCLUDE_BYTES = 10514,      /* KW_INCLUDE_BYTES  */
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
-    KW_FETCH_NO_DATA_DELAY = 10522 /* KW_FETCH_NO_DATA_DELAY  */
+    KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
+    KW_LABELS = 10530              /* KW_LABELS  */
   };
   typedef enum afsocket_tokentype afsocket_token_kind_t;
 #endif
@@ -421,7 +427,9 @@ extern int afsocket_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -439,6 +447,7 @@ extern int afsocket_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -453,6 +462,7 @@ extern int afsocket_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -579,6 +589,7 @@ extern int afsocket_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -596,6 +607,7 @@ extern int afsocket_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
+#define KW_LABELS 10530
 
 /* Value type.  */
 #if ! defined AFSOCKET_STYPE && ! defined AFSOCKET_STYPE_IS_DECLARED
