@@ -939,7 +939,7 @@ afsocket_sd_setup_reader_options(AFSocketSourceDriver *self)
       if (self->reader_options.super.init_window_size < min_iw_size_per_reader)
         {
           msg_warning("WARNING: window sizing for tcp sources were changed in " VERSION_3_3
-                      ", the configuration value was divided by the value of max-connections(). The result was too small, clamping to value of min_iw_size_per_reader. Ensure you have a proper log_fifo_size setting to avoid message loss.",
+                      ", the configuration value was divided by the value of max-connections(). The result was too small, increasing to a reasonable minimum value",
                       evt_tag_int("orig_log_iw_size", self->reader_options.super.init_window_size),
                       evt_tag_int("new_log_iw_size", min_iw_size_per_reader),
                       evt_tag_int("min_iw_size_per_reader", min_iw_size_per_reader),
