@@ -29,6 +29,7 @@
 #include "transport/multitransport.h"
 #include "transport/transport-factory-tls.h"
 #include "transport/transport-factory-socket.h"
+#include "transport/transport-udp-socket.h"
 #include "secret-storage/secret-storage.h"
 
 #include <sys/types.h>
@@ -62,13 +63,11 @@ transport_mapper_inet_validate_tls_options(TransportMapperInet *self)
   if (!self->tls_context && _is_tls_required(self))
     {
       msg_error("transport(tls) was specified, but tls() options missing");
-      // evt_tag_str("id", self->super.super.super.id),
       return FALSE;
     }
   else if (self->tls_context && !_is_tls_allowed(self))
     {
       msg_error("tls() options specified for a transport that doesn't allow TLS encryption",
-                //evt_tag_str("id", self->super.super.super.id),
                 evt_tag_str("transport", self->super.transport));
       return FALSE;
     }
@@ -89,7 +88,7 @@ transport_mapper_inet_apply_transport_method(TransportMapper *s, GlobalConfig *c
 static LogTransport *
 _construct_multitransport_with_tls_factory(TransportMapperInet *self, gint fd)
 {
-  TransportFactory *default_factory = transport_factory_tls_new(self->tls_context, self->tls_verifier);
+  TransportFactory *default_factory = transport_factory_tls_new(self->tls_context, self->tls_verifier, self->flags);
   return multitransport_new(default_factory, fd);
 }
 
@@ -103,6 +102,7 @@ _construct_tls_transport(TransportMapperInet *self, gint fd)
   if (!tls_session)
     return NULL;
 
+  tls_session_configure_allow_compress(tls_session, self->flags & TMI_ALLOW_COMPRESS);
   tls_session_set_verifier(tls_session, self->tls_verifier);
 
   return log_transport_tls_new(tls_session, fd);
@@ -121,7 +121,7 @@ _construct_multitransport_with_plain_and_tls_factories(TransportMapperInet *self
 {
   LogTransport *transport = _construct_multitransport_with_plain_tcp_factory(self, fd);
 
-  TransportFactory *tls_factory = transport_factory_tls_new(self->tls_context, self->tls_verifier);
+  TransportFactory *tls_factory = transport_factory_tls_new(self->tls_context, self->tls_verifier, self->flags);
   multitransport_add_factory((MultiTransport *)transport, tls_factory);
 
   return transport;
@@ -133,7 +133,10 @@ _construct_plain_tcp_transport(TransportMapperInet *self, gint fd)
   if (self->super.create_multitransport)
     return _construct_multitransport_with_plain_tcp_factory(self, fd);
 
-  return transport_mapper_construct_log_transport_method(&self->super, fd);
+  if (self->super.sock_type == SOCK_DGRAM)
+    return log_transport_udp_socket_new(fd);
+  else
+    return log_transport_stream_socket_new(fd);
 }
 
 static LogTransport *
@@ -302,15 +305,32 @@ transport_mapper_inet_new_instance(const gchar *transport)
   return self;
 }
 
+static gboolean
+transport_mapper_tcp_apply_transport(TransportMapper *s, GlobalConfig *cfg)
+{
+  TransportMapperInet *self = (TransportMapperInet *) s;
+
+  if (!transport_mapper_inet_apply_transport_method(s, cfg))
+    return FALSE;
+
+  if (self->tls_context)
+    self->super.transport_name = g_strdup("rfc3164+tls");
+  else
+    self->super.transport_name = g_strdup("rfc3164+tcp");
+
+  return TRUE;
+}
+
 TransportMapper *
 transport_mapper_tcp_new(void)
 {
   TransportMapperInet *self = transport_mapper_inet_new_instance("tcp");
 
+  self->super.apply_transport = transport_mapper_tcp_apply_transport;
   self->super.sock_type = SOCK_STREAM;
   self->super.sock_proto = IPPROTO_TCP;
   self->super.logproto = "text";
-  self->super.stats_source = SCS_TCP;
+  self->super.stats_source = stats_register_type("tcp");
   self->server_port = TCP_PORT;
   self->require_tls_when_has_tls_context = TRUE;
   return &self->super;
@@ -322,7 +342,7 @@ transport_mapper_tcp6_new(void)
   TransportMapper *self = transport_mapper_tcp_new();
 
   self->address_family = AF_INET6;
-  self->stats_source = SCS_TCP6;
+  self->stats_source = stats_register_type("tcp6");
   return self;
 }
 
@@ -331,10 +351,11 @@ transport_mapper_udp_new(void)
 {
   TransportMapperInet *self = transport_mapper_inet_new_instance("udp");
 
+  self->super.transport_name = g_strdup("rfc3164+udp");
   self->super.sock_type = SOCK_DGRAM;
   self->super.sock_proto = IPPROTO_UDP;
   self->super.logproto = "dgram";
-  self->super.stats_source = SCS_UDP;
+  self->super.stats_source = stats_register_type("udp");
   self->server_port = UDP_PORT;
   return &self->super;
 }
@@ -345,7 +366,7 @@ transport_mapper_udp6_new(void)
   TransportMapper *self = transport_mapper_udp_new();
 
   self->address_family = AF_INET6;
-  self->stats_source = SCS_UDP6;
+  self->stats_source = stats_register_type("udp6");
   return self;
 }
 
@@ -367,12 +388,14 @@ transport_mapper_network_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       self->super.sock_type = SOCK_DGRAM;
       self->super.sock_proto = IPPROTO_UDP;
       self->super.logproto = "dgram";
+      self->super.transport_name = g_strdup("rfc3164+udp");
     }
   else if (strcasecmp(transport, "tcp") == 0)
     {
       self->super.logproto = "text";
       self->super.sock_type = SOCK_STREAM;
       self->super.sock_proto = IPPROTO_TCP;
+      self->super.transport_name = g_strdup("rfc3164+tcp");
     }
   else if (strcasecmp(transport, "tls") == 0)
     {
@@ -380,6 +403,15 @@ transport_mapper_network_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       self->super.sock_type = SOCK_STREAM;
       self->super.sock_proto = IPPROTO_TCP;
       self->require_tls = TRUE;
+      self->super.transport_name = g_strdup("rfc3164+tls");
+    }
+  else if (strcasecmp(transport, "proxied-tls") == 0)
+    {
+      self->super.logproto = "proxied-tcp";
+      self->super.sock_type = SOCK_STREAM;
+      self->super.sock_proto = IPPROTO_TCP;
+      self->require_tls = TRUE;
+      self->super.transport_name = g_strdup("rfc3164+proxied-tls");
     }
   else
     {
@@ -389,6 +421,7 @@ transport_mapper_network_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       /* FIXME: look up port/protocol from the logproto */
       self->server_port = TCP_PORT;
       self->allow_tls = TRUE;
+      self->super.transport_name = g_strdup_printf("rfc3164+%s", self->super.transport);
     }
 
   g_assert(self->server_port != 0);
@@ -405,7 +438,7 @@ transport_mapper_network_new(void)
   TransportMapperInet *self = transport_mapper_inet_new_instance("tcp");
 
   self->super.apply_transport = transport_mapper_network_apply_transport;
-  self->super.stats_source = SCS_NETWORK;
+  self->super.stats_source = stats_register_type("network");
   return &self->super;
 }
 
@@ -422,7 +455,7 @@ transport_mapper_syslog_apply_transport(TransportMapper *s, GlobalConfig *cfg)
 
   if (strcasecmp(transport, "udp") == 0)
     {
-      if (cfg_is_config_version_older(cfg, 0x0303))
+      if (cfg_is_config_version_older(cfg, VERSION_VALUE_3_3))
         {
           self->server_port_change_warning = "WARNING: Default port for syslog(transport(udp)) has changed from 601 to 514 in "
                                              VERSION_3_3 ", please update your configuration";
@@ -434,6 +467,7 @@ transport_mapper_syslog_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       self->super.sock_type = SOCK_DGRAM;
       self->super.sock_proto = IPPROTO_UDP;
       self->super.logproto = "dgram";
+      self->super.transport_name = g_strdup("rfc5426");
     }
   else if (strcasecmp(transport, "tcp") == 0)
     {
@@ -441,10 +475,11 @@ transport_mapper_syslog_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       self->super.logproto = "framed";
       self->super.sock_type = SOCK_STREAM;
       self->super.sock_proto = IPPROTO_TCP;
+      self->super.transport_name = g_strdup("rfc6587");
     }
   else if (strcasecmp(transport, "tls") == 0)
     {
-      if (cfg_is_config_version_older(cfg, 0x0303))
+      if (cfg_is_config_version_older(cfg, VERSION_VALUE_3_3))
         {
           self->server_port_change_warning = "WARNING: Default port for syslog(transport(tls))  has changed from 601 to 6514 in "
                                              VERSION_3_3 ", please update your configuration";
@@ -456,6 +491,7 @@ transport_mapper_syslog_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       self->super.sock_type = SOCK_STREAM;
       self->super.sock_proto = IPPROTO_TCP;
       self->require_tls = TRUE;
+      self->super.transport_name = g_strdup("rfc5425");
     }
   else
     {
@@ -465,6 +501,7 @@ transport_mapper_syslog_apply_transport(TransportMapper *s, GlobalConfig *cfg)
       self->server_port = 514;
       self->super.sock_proto = IPPROTO_TCP;
       self->allow_tls = TRUE;
+      self->super.transport_name = g_strdup_printf("rfc5424+%s", self->super.transport);
     }
   g_assert(self->server_port != 0);
 
@@ -480,6 +517,6 @@ transport_mapper_syslog_new(void)
   TransportMapperInet *self = transport_mapper_inet_new_instance("tcp");
 
   self->super.apply_transport = transport_mapper_syslog_apply_transport;
-  self->super.stats_source = SCS_SYSLOG;
+  self->super.stats_source = stats_register_type("syslog");
   return &self->super;
 }
