@@ -69,7 +69,7 @@ extern int afstomp_debug;
     AFSTOMP_EMPTY = -2,
     AFSTOMP_EOF = 0,               /* "end of file"  */
     AFSTOMP_error = 256,           /* error  */
-    AFSTOMP_UNDEF = 10523,         /* "invalid token"  */
+    AFSTOMP_UNDEF = 10531,         /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -92,7 +92,9 @@ extern int afstomp_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -110,6 +112,7 @@ extern int afstomp_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -124,6 +127,7 @@ extern int afstomp_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -250,6 +254,7 @@ extern int afstomp_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -267,13 +272,14 @@ extern int afstomp_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_STOMP = 10524,              /* KW_STOMP  */
-    KW_STOMP_DESTINATION = 10525,  /* KW_STOMP_DESTINATION  */
-    KW_PERSISTENT = 10526,         /* KW_PERSISTENT  */
-    KW_ACK = 10527,                /* KW_ACK  */
-    KW_BODY = 10528,               /* KW_BODY  */
-    KW_PASSWORD = 10529,           /* KW_PASSWORD  */
-    KW_USERNAME = 10530            /* KW_USERNAME  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_STOMP = 10532,              /* KW_STOMP  */
+    KW_STOMP_DESTINATION = 10533,  /* KW_STOMP_DESTINATION  */
+    KW_PERSISTENT = 10534,         /* KW_PERSISTENT  */
+    KW_ACK = 10535,                /* KW_ACK  */
+    KW_BODY = 10536,               /* KW_BODY  */
+    KW_PASSWORD = 10537,           /* KW_PASSWORD  */
+    KW_USERNAME = 10538            /* KW_USERNAME  */
   };
   typedef enum afstomp_tokentype afstomp_token_kind_t;
 #endif
@@ -281,7 +287,7 @@ extern int afstomp_debug;
 #define AFSTOMP_EMPTY -2
 #define AFSTOMP_EOF 0
 #define AFSTOMP_error 256
-#define AFSTOMP_UNDEF 10523
+#define AFSTOMP_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -304,7 +310,9 @@ extern int afstomp_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -322,6 +330,7 @@ extern int afstomp_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -336,6 +345,7 @@ extern int afstomp_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -462,6 +472,7 @@ extern int afstomp_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -479,13 +490,14 @@ extern int afstomp_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_STOMP 10524
-#define KW_STOMP_DESTINATION 10525
-#define KW_PERSISTENT 10526
-#define KW_ACK 10527
-#define KW_BODY 10528
-#define KW_PASSWORD 10529
-#define KW_USERNAME 10530
+#define KW_LABELS 10530
+#define KW_STOMP 10532
+#define KW_STOMP_DESTINATION 10533
+#define KW_PERSISTENT 10534
+#define KW_ACK 10535
+#define KW_BODY 10536
+#define KW_PASSWORD 10537
+#define KW_USERNAME 10538
 
 /* Value type.  */
 #if ! defined AFSTOMP_STYPE && ! defined AFSTOMP_STYPE_IS_DECLARED
