@@ -61,7 +61,7 @@ extern int bigquery_debug;
     BIGQUERY_EMPTY = -2,
     BIGQUERY_EOF = 0,              /* "end of file"  */
     BIGQUERY_error = 256,          /* error  */
-    BIGQUERY_UNDEF = 10523,        /* "invalid token"  */
+    BIGQUERY_UNDEF = 10531,        /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -84,7 +84,9 @@ extern int bigquery_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -102,6 +104,7 @@ extern int bigquery_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -116,6 +119,7 @@ extern int bigquery_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -242,6 +246,7 @@ extern int bigquery_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -259,19 +264,21 @@ extern int bigquery_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_BIGQUERY = 10524,           /* KW_BIGQUERY  */
-    KW_URL = 10525,                /* KW_URL  */
-    KW_PROJECT = 10526,            /* KW_PROJECT  */
-    KW_DATASET = 10527,            /* KW_DATASET  */
-    KW_TABLE = 10528,              /* KW_TABLE  */
-    KW_SCHEMA = 10529,             /* KW_SCHEMA  */
-    KW_PROTOBUF_SCHEMA = 10530,    /* KW_PROTOBUF_SCHEMA  */
-    KW_BATCH_BYTES = 10531,        /* KW_BATCH_BYTES  */
-    KW_COMPRESSION = 10532,        /* KW_COMPRESSION  */
-    KW_KEEP_ALIVE = 10533,         /* KW_KEEP_ALIVE  */
-    KW_TIME = 10534,               /* KW_TIME  */
-    KW_TIMEOUT = 10535,            /* KW_TIMEOUT  */
-    KW_MAX_PINGS_WITHOUT_DATA = 10536 /* KW_MAX_PINGS_WITHOUT_DATA  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_BIGQUERY = 10532,           /* KW_BIGQUERY  */
+    KW_URL = 10533,                /* KW_URL  */
+    KW_PROJECT = 10534,            /* KW_PROJECT  */
+    KW_DATASET = 10535,            /* KW_DATASET  */
+    KW_TABLE = 10536,              /* KW_TABLE  */
+    KW_SCHEMA = 10537,             /* KW_SCHEMA  */
+    KW_PROTOBUF_SCHEMA = 10538,    /* KW_PROTOBUF_SCHEMA  */
+    KW_BATCH_BYTES = 10539,        /* KW_BATCH_BYTES  */
+    KW_COMPRESSION = 10540,        /* KW_COMPRESSION  */
+    KW_KEEP_ALIVE = 10541,         /* KW_KEEP_ALIVE  */
+    KW_TIME = 10542,               /* KW_TIME  */
+    KW_TIMEOUT = 10543,            /* KW_TIMEOUT  */
+    KW_MAX_PINGS_WITHOUT_DATA = 10544, /* KW_MAX_PINGS_WITHOUT_DATA  */
+    KW_CHANNEL_ARGS = 10545        /* KW_CHANNEL_ARGS  */
   };
   typedef enum bigquery_tokentype bigquery_token_kind_t;
 #endif
@@ -279,7 +286,7 @@ extern int bigquery_debug;
 #define BIGQUERY_EMPTY -2
 #define BIGQUERY_EOF 0
 #define BIGQUERY_error 256
-#define BIGQUERY_UNDEF 10523
+#define BIGQUERY_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -302,7 +309,9 @@ extern int bigquery_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -320,6 +329,7 @@ extern int bigquery_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -334,6 +344,7 @@ extern int bigquery_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -460,6 +471,7 @@ extern int bigquery_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -477,19 +489,21 @@ extern int bigquery_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_BIGQUERY 10524
-#define KW_URL 10525
-#define KW_PROJECT 10526
-#define KW_DATASET 10527
-#define KW_TABLE 10528
-#define KW_SCHEMA 10529
-#define KW_PROTOBUF_SCHEMA 10530
-#define KW_BATCH_BYTES 10531
-#define KW_COMPRESSION 10532
-#define KW_KEEP_ALIVE 10533
-#define KW_TIME 10534
-#define KW_TIMEOUT 10535
-#define KW_MAX_PINGS_WITHOUT_DATA 10536
+#define KW_LABELS 10530
+#define KW_BIGQUERY 10532
+#define KW_URL 10533
+#define KW_PROJECT 10534
+#define KW_DATASET 10535
+#define KW_TABLE 10536
+#define KW_SCHEMA 10537
+#define KW_PROTOBUF_SCHEMA 10538
+#define KW_BATCH_BYTES 10539
+#define KW_COMPRESSION 10540
+#define KW_KEEP_ALIVE 10541
+#define KW_TIME 10542
+#define KW_TIMEOUT 10543
+#define KW_MAX_PINGS_WITHOUT_DATA 10544
+#define KW_CHANNEL_ARGS 10545
 
 /* Value type.  */
 #if ! defined BIGQUERY_STYPE && ! defined BIGQUERY_STYPE_IS_DECLARED
