@@ -36,6 +36,8 @@ LogDriver *otel_dd_new(GlobalConfig *cfg);
 void otel_dd_set_url(LogDriver *s, const gchar *url);
 void otel_dd_set_compression(LogDriver *s, gboolean enable);
 void otel_dd_set_batch_bytes(LogDriver *s, glong b);
+void otel_dd_add_int_channel_arg(LogDriver *s, const gchar *name, glong value);
+void otel_dd_add_string_channel_arg(LogDriver *s, const gchar *name, const gchar *value);
 GrpcClientCredentialsBuilderW *otel_dd_get_credentials_builder(LogDriver *s);
 
 #include "compat/cpp-end.h"
