@@ -61,7 +61,7 @@ extern int otel_debug;
     OTEL_EMPTY = -2,
     OTEL_EOF = 0,                  /* "end of file"  */
     OTEL_error = 256,              /* error  */
-    OTEL_UNDEF = 10523,            /* "invalid token"  */
+    OTEL_UNDEF = 10531,            /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -84,7 +84,9 @@ extern int otel_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -102,6 +104,7 @@ extern int otel_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -116,6 +119,7 @@ extern int otel_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -242,6 +246,7 @@ extern int otel_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -259,25 +264,28 @@ extern int otel_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_OPENTELEMETRY = 10524,      /* KW_OPENTELEMETRY  */
-    KW_AUTH = 10525,               /* KW_AUTH  */
-    KW_INSECURE = 10526,           /* KW_INSECURE  */
-    KW_TLS = 10527,                /* KW_TLS  */
-    KW_KEY_FILE = 10528,           /* KW_KEY_FILE  */
-    KW_CERT_FILE = 10529,          /* KW_CERT_FILE  */
-    KW_CA_FILE = 10530,            /* KW_CA_FILE  */
-    KW_PEER_VERIFY = 10531,        /* KW_PEER_VERIFY  */
-    KW_OPTIONAL_UNTRUSTED = 10532, /* KW_OPTIONAL_UNTRUSTED  */
-    KW_OPTIONAL_TRUSTED = 10533,   /* KW_OPTIONAL_TRUSTED  */
-    KW_REQUIRED_UNTRUSTED = 10534, /* KW_REQUIRED_UNTRUSTED  */
-    KW_REQUIRED_TRUSTED = 10535,   /* KW_REQUIRED_TRUSTED  */
-    KW_ALTS = 10536,               /* KW_ALTS  */
-    KW_URL = 10537,                /* KW_URL  */
-    KW_TARGET_SERVICE_ACCOUNTS = 10538, /* KW_TARGET_SERVICE_ACCOUNTS  */
-    KW_ADC = 10539,                /* KW_ADC  */
-    KW_SYSLOG_NG_OTLP = 10540,     /* KW_SYSLOG_NG_OTLP  */
-    KW_COMPRESSION = 10541,        /* KW_COMPRESSION  */
-    KW_BATCH_BYTES = 10542         /* KW_BATCH_BYTES  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_OPENTELEMETRY = 10532,      /* KW_OPENTELEMETRY  */
+    KW_AUTH = 10533,               /* KW_AUTH  */
+    KW_INSECURE = 10534,           /* KW_INSECURE  */
+    KW_TLS = 10535,                /* KW_TLS  */
+    KW_KEY_FILE = 10536,           /* KW_KEY_FILE  */
+    KW_CERT_FILE = 10537,          /* KW_CERT_FILE  */
+    KW_CA_FILE = 10538,            /* KW_CA_FILE  */
+    KW_PEER_VERIFY = 10539,        /* KW_PEER_VERIFY  */
+    KW_OPTIONAL_UNTRUSTED = 10540, /* KW_OPTIONAL_UNTRUSTED  */
+    KW_OPTIONAL_TRUSTED = 10541,   /* KW_OPTIONAL_TRUSTED  */
+    KW_REQUIRED_UNTRUSTED = 10542, /* KW_REQUIRED_UNTRUSTED  */
+    KW_REQUIRED_TRUSTED = 10543,   /* KW_REQUIRED_TRUSTED  */
+    KW_ALTS = 10544,               /* KW_ALTS  */
+    KW_URL = 10545,                /* KW_URL  */
+    KW_TARGET_SERVICE_ACCOUNTS = 10546, /* KW_TARGET_SERVICE_ACCOUNTS  */
+    KW_ADC = 10547,                /* KW_ADC  */
+    KW_SYSLOG_NG_OTLP = 10548,     /* KW_SYSLOG_NG_OTLP  */
+    KW_COMPRESSION = 10549,        /* KW_COMPRESSION  */
+    KW_BATCH_BYTES = 10550,        /* KW_BATCH_BYTES  */
+    KW_CONCURRENT_REQUESTS = 10551, /* KW_CONCURRENT_REQUESTS  */
+    KW_CHANNEL_ARGS = 10552        /* KW_CHANNEL_ARGS  */
   };
   typedef enum otel_tokentype otel_token_kind_t;
 #endif
@@ -285,7 +293,7 @@ extern int otel_debug;
 #define OTEL_EMPTY -2
 #define OTEL_EOF 0
 #define OTEL_error 256
-#define OTEL_UNDEF 10523
+#define OTEL_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -308,7 +316,9 @@ extern int otel_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -326,6 +336,7 @@ extern int otel_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -340,6 +351,7 @@ extern int otel_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -466,6 +478,7 @@ extern int otel_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -483,25 +496,28 @@ extern int otel_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_OPENTELEMETRY 10524
-#define KW_AUTH 10525
-#define KW_INSECURE 10526
-#define KW_TLS 10527
-#define KW_KEY_FILE 10528
-#define KW_CERT_FILE 10529
-#define KW_CA_FILE 10530
-#define KW_PEER_VERIFY 10531
-#define KW_OPTIONAL_UNTRUSTED 10532
-#define KW_OPTIONAL_TRUSTED 10533
-#define KW_REQUIRED_UNTRUSTED 10534
-#define KW_REQUIRED_TRUSTED 10535
-#define KW_ALTS 10536
-#define KW_URL 10537
-#define KW_TARGET_SERVICE_ACCOUNTS 10538
-#define KW_ADC 10539
-#define KW_SYSLOG_NG_OTLP 10540
-#define KW_COMPRESSION 10541
-#define KW_BATCH_BYTES 10542
+#define KW_LABELS 10530
+#define KW_OPENTELEMETRY 10532
+#define KW_AUTH 10533
+#define KW_INSECURE 10534
+#define KW_TLS 10535
+#define KW_KEY_FILE 10536
+#define KW_CERT_FILE 10537
+#define KW_CA_FILE 10538
+#define KW_PEER_VERIFY 10539
+#define KW_OPTIONAL_UNTRUSTED 10540
+#define KW_OPTIONAL_TRUSTED 10541
+#define KW_REQUIRED_UNTRUSTED 10542
+#define KW_REQUIRED_TRUSTED 10543
+#define KW_ALTS 10544
+#define KW_URL 10545
+#define KW_TARGET_SERVICE_ACCOUNTS 10546
+#define KW_ADC 10547
+#define KW_SYSLOG_NG_OTLP 10548
+#define KW_COMPRESSION 10549
+#define KW_BATCH_BYTES 10550
+#define KW_CONCURRENT_REQUESTS 10551
+#define KW_CHANNEL_ARGS 10552
 
 /* Value type.  */
 #if ! defined OTEL_STYPE && ! defined OTEL_STYPE_IS_DECLARED
