@@ -61,7 +61,7 @@ extern int hook_commands_debug;
     HOOK_COMMANDS_EMPTY = -2,
     HOOK_COMMANDS_EOF = 0,         /* "end of file"  */
     HOOK_COMMANDS_error = 256,     /* error  */
-    HOOK_COMMANDS_UNDEF = 10523,   /* "invalid token"  */
+    HOOK_COMMANDS_UNDEF = 10531,   /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -84,7 +84,9 @@ extern int hook_commands_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -102,6 +104,7 @@ extern int hook_commands_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -116,6 +119,7 @@ extern int hook_commands_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -242,6 +246,7 @@ extern int hook_commands_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -259,11 +264,12 @@ extern int hook_commands_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_HOOK_COMMANDS = 10524,      /* KW_HOOK_COMMANDS  */
-    KW_STARTUP = 10525,            /* KW_STARTUP  */
-    KW_SETUP = 10526,              /* KW_SETUP  */
-    KW_TEARDOWN = 10527,           /* KW_TEARDOWN  */
-    KW_SHUTDOWN = 10528            /* KW_SHUTDOWN  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_HOOK_COMMANDS = 10532,      /* KW_HOOK_COMMANDS  */
+    KW_STARTUP = 10533,            /* KW_STARTUP  */
+    KW_SETUP = 10534,              /* KW_SETUP  */
+    KW_TEARDOWN = 10535,           /* KW_TEARDOWN  */
+    KW_SHUTDOWN = 10536            /* KW_SHUTDOWN  */
   };
   typedef enum hook_commands_tokentype hook_commands_token_kind_t;
 #endif
@@ -271,7 +277,7 @@ extern int hook_commands_debug;
 #define HOOK_COMMANDS_EMPTY -2
 #define HOOK_COMMANDS_EOF 0
 #define HOOK_COMMANDS_error 256
-#define HOOK_COMMANDS_UNDEF 10523
+#define HOOK_COMMANDS_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -294,7 +300,9 @@ extern int hook_commands_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -312,6 +320,7 @@ extern int hook_commands_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -326,6 +335,7 @@ extern int hook_commands_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -452,6 +462,7 @@ extern int hook_commands_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -469,11 +480,12 @@ extern int hook_commands_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_HOOK_COMMANDS 10524
-#define KW_STARTUP 10525
-#define KW_SETUP 10526
-#define KW_TEARDOWN 10527
-#define KW_SHUTDOWN 10528
+#define KW_LABELS 10530
+#define KW_HOOK_COMMANDS 10532
+#define KW_STARTUP 10533
+#define KW_SETUP 10534
+#define KW_TEARDOWN 10535
+#define KW_SHUTDOWN 10536
 
 /* Value type.  */
 #if ! defined HOOK_COMMANDS_STYPE && ! defined HOOK_COMMANDS_STYPE_IS_DECLARED
