@@ -61,42 +61,42 @@ extern int http_debug;
     HTTP_EMPTY = -2,
     HTTP_EOF = 0,                  /* "end of file"  */
     HTTP_error = 256,              /* error  */
-    HTTP_UNDEF = 10523,            /* "invalid token"  */
-    KW_HTTP = 10524,               /* KW_HTTP  */
-    KW_URL = 10525,                /* KW_URL  */
-    KW_USER = 10526,               /* KW_USER  */
-    KW_PASSWORD = 10527,           /* KW_PASSWORD  */
-    KW_USER_AGENT = 10528,         /* KW_USER_AGENT  */
-    KW_METHOD = 10529,             /* KW_METHOD  */
-    KW_HEADERS = 10530,            /* KW_HEADERS  */
-    KW_BODY = 10531,               /* KW_BODY  */
-    KW_CA_DIR = 10532,             /* KW_CA_DIR  */
-    KW_CA_FILE = 10533,            /* KW_CA_FILE  */
-    KW_CERT_FILE = 10534,          /* KW_CERT_FILE  */
-    KW_KEY_FILE = 10535,           /* KW_KEY_FILE  */
-    KW_CIPHER_SUITE = 10536,       /* KW_CIPHER_SUITE  */
-    KW_TLS12_AND_OLDER = 10537,    /* KW_TLS12_AND_OLDER  */
-    KW_TLS13 = 10538,              /* KW_TLS13  */
-    KW_PROXY = 10539,              /* KW_PROXY  */
-    KW_USE_SYSTEM_CERT_STORE = 10540, /* KW_USE_SYSTEM_CERT_STORE  */
-    KW_SSL_VERSION = 10541,        /* KW_SSL_VERSION  */
-    KW_PEER_VERIFY = 10542,        /* KW_PEER_VERIFY  */
-    KW_TIMEOUT = 10543,            /* KW_TIMEOUT  */
-    KW_OCSP_STAPLING_VERIFY = 10544, /* KW_OCSP_STAPLING_VERIFY  */
-    KW_TLS = 10545,                /* KW_TLS  */
-    KW_ACCEPT_ENCODING = 10546,    /* KW_ACCEPT_ENCODING  */
-    KW_CONTENT_COMPRESSION = 10547, /* KW_CONTENT_COMPRESSION  */
-    KW_BATCH_BYTES = 10548,        /* KW_BATCH_BYTES  */
-    KW_BODY_PREFIX = 10549,        /* KW_BODY_PREFIX  */
-    KW_BODY_SUFFIX = 10550,        /* KW_BODY_SUFFIX  */
-    KW_DELIMITER = 10551,          /* KW_DELIMITER  */
-    KW_ACCEPT_REDIRECTS = 10552,   /* KW_ACCEPT_REDIRECTS  */
-    KW_RESPONSE_ACTION = 10553,    /* KW_RESPONSE_ACTION  */
-    KW_SUCCESS = 10554,            /* KW_SUCCESS  */
-    KW_RETRY = 10555,              /* KW_RETRY  */
-    KW_DROP = 10556,               /* KW_DROP  */
-    KW_DISCONNECT = 10557,         /* KW_DISCONNECT  */
-    KW_FLUSH_ON_WORKER_KEY_CHANGE = 10558, /* KW_FLUSH_ON_WORKER_KEY_CHANGE  */
+    HTTP_UNDEF = 10531,            /* "invalid token"  */
+    KW_HTTP = 10532,               /* KW_HTTP  */
+    KW_URL = 10533,                /* KW_URL  */
+    KW_USER = 10534,               /* KW_USER  */
+    KW_PASSWORD = 10535,           /* KW_PASSWORD  */
+    KW_USER_AGENT = 10536,         /* KW_USER_AGENT  */
+    KW_METHOD = 10537,             /* KW_METHOD  */
+    KW_HEADERS = 10538,            /* KW_HEADERS  */
+    KW_BODY = 10539,               /* KW_BODY  */
+    KW_CA_DIR = 10540,             /* KW_CA_DIR  */
+    KW_CA_FILE = 10541,            /* KW_CA_FILE  */
+    KW_CERT_FILE = 10542,          /* KW_CERT_FILE  */
+    KW_KEY_FILE = 10543,           /* KW_KEY_FILE  */
+    KW_CIPHER_SUITE = 10544,       /* KW_CIPHER_SUITE  */
+    KW_TLS12_AND_OLDER = 10545,    /* KW_TLS12_AND_OLDER  */
+    KW_TLS13 = 10546,              /* KW_TLS13  */
+    KW_PROXY = 10547,              /* KW_PROXY  */
+    KW_USE_SYSTEM_CERT_STORE = 10548, /* KW_USE_SYSTEM_CERT_STORE  */
+    KW_SSL_VERSION = 10549,        /* KW_SSL_VERSION  */
+    KW_PEER_VERIFY = 10550,        /* KW_PEER_VERIFY  */
+    KW_TIMEOUT = 10551,            /* KW_TIMEOUT  */
+    KW_OCSP_STAPLING_VERIFY = 10552, /* KW_OCSP_STAPLING_VERIFY  */
+    KW_TLS = 10553,                /* KW_TLS  */
+    KW_ACCEPT_ENCODING = 10554,    /* KW_ACCEPT_ENCODING  */
+    KW_CONTENT_COMPRESSION = 10555, /* KW_CONTENT_COMPRESSION  */
+    KW_BATCH_BYTES = 10556,        /* KW_BATCH_BYTES  */
+    KW_BODY_PREFIX = 10557,        /* KW_BODY_PREFIX  */
+    KW_BODY_SUFFIX = 10558,        /* KW_BODY_SUFFIX  */
+    KW_DELIMITER = 10559,          /* KW_DELIMITER  */
+    KW_ACCEPT_REDIRECTS = 10560,   /* KW_ACCEPT_REDIRECTS  */
+    KW_RESPONSE_ACTION = 10561,    /* KW_RESPONSE_ACTION  */
+    KW_SUCCESS = 10562,            /* KW_SUCCESS  */
+    KW_RETRY = 10563,              /* KW_RETRY  */
+    KW_DROP = 10564,               /* KW_DROP  */
+    KW_DISCONNECT = 10565,         /* KW_DISCONNECT  */
+    KW_FLUSH_ON_WORKER_KEY_CHANGE = 10566, /* KW_FLUSH_ON_WORKER_KEY_CHANGE  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -119,7 +119,9 @@ extern int http_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -137,6 +139,7 @@ extern int http_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -151,6 +154,7 @@ extern int http_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -277,6 +281,7 @@ extern int http_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -293,7 +298,8 @@ extern int http_debug;
     KW_INCLUDE_BYTES = 10514,      /* KW_INCLUDE_BYTES  */
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
-    KW_FETCH_NO_DATA_DELAY = 10522 /* KW_FETCH_NO_DATA_DELAY  */
+    KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
+    KW_LABELS = 10530              /* KW_LABELS  */
   };
   typedef enum http_tokentype http_token_kind_t;
 #endif
@@ -301,42 +307,42 @@ extern int http_debug;
 #define HTTP_EMPTY -2
 #define HTTP_EOF 0
 #define HTTP_error 256
-#define HTTP_UNDEF 10523
-#define KW_HTTP 10524
-#define KW_URL 10525
-#define KW_USER 10526
-#define KW_PASSWORD 10527
-#define KW_USER_AGENT 10528
-#define KW_METHOD 10529
-#define KW_HEADERS 10530
-#define KW_BODY 10531
-#define KW_CA_DIR 10532
-#define KW_CA_FILE 10533
-#define KW_CERT_FILE 10534
-#define KW_KEY_FILE 10535
-#define KW_CIPHER_SUITE 10536
-#define KW_TLS12_AND_OLDER 10537
-#define KW_TLS13 10538
-#define KW_PROXY 10539
-#define KW_USE_SYSTEM_CERT_STORE 10540
-#define KW_SSL_VERSION 10541
-#define KW_PEER_VERIFY 10542
-#define KW_TIMEOUT 10543
-#define KW_OCSP_STAPLING_VERIFY 10544
-#define KW_TLS 10545
-#define KW_ACCEPT_ENCODING 10546
-#define KW_CONTENT_COMPRESSION 10547
-#define KW_BATCH_BYTES 10548
-#define KW_BODY_PREFIX 10549
-#define KW_BODY_SUFFIX 10550
-#define KW_DELIMITER 10551
-#define KW_ACCEPT_REDIRECTS 10552
-#define KW_RESPONSE_ACTION 10553
-#define KW_SUCCESS 10554
-#define KW_RETRY 10555
-#define KW_DROP 10556
-#define KW_DISCONNECT 10557
-#define KW_FLUSH_ON_WORKER_KEY_CHANGE 10558
+#define HTTP_UNDEF 10531
+#define KW_HTTP 10532
+#define KW_URL 10533
+#define KW_USER 10534
+#define KW_PASSWORD 10535
+#define KW_USER_AGENT 10536
+#define KW_METHOD 10537
+#define KW_HEADERS 10538
+#define KW_BODY 10539
+#define KW_CA_DIR 10540
+#define KW_CA_FILE 10541
+#define KW_CERT_FILE 10542
+#define KW_KEY_FILE 10543
+#define KW_CIPHER_SUITE 10544
+#define KW_TLS12_AND_OLDER 10545
+#define KW_TLS13 10546
+#define KW_PROXY 10547
+#define KW_USE_SYSTEM_CERT_STORE 10548
+#define KW_SSL_VERSION 10549
+#define KW_PEER_VERIFY 10550
+#define KW_TIMEOUT 10551
+#define KW_OCSP_STAPLING_VERIFY 10552
+#define KW_TLS 10553
+#define KW_ACCEPT_ENCODING 10554
+#define KW_CONTENT_COMPRESSION 10555
+#define KW_BATCH_BYTES 10556
+#define KW_BODY_PREFIX 10557
+#define KW_BODY_SUFFIX 10558
+#define KW_DELIMITER 10559
+#define KW_ACCEPT_REDIRECTS 10560
+#define KW_RESPONSE_ACTION 10561
+#define KW_SUCCESS 10562
+#define KW_RETRY 10563
+#define KW_DROP 10564
+#define KW_DISCONNECT 10565
+#define KW_FLUSH_ON_WORKER_KEY_CHANGE 10566
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -359,7 +365,9 @@ extern int http_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -377,6 +385,7 @@ extern int http_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -391,6 +400,7 @@ extern int http_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -517,6 +527,7 @@ extern int http_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -534,6 +545,7 @@ extern int http_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
+#define KW_LABELS 10530
 
 /* Value type.  */
 #if ! defined HTTP_STYPE && ! defined HTTP_STYPE_IS_DECLARED
