@@ -28,6 +28,16 @@
 #include "scratch-buffers.h"
 #include "http-signals.h"
 
+enum HttpRequestsMetricLabelIds
+{
+  HTTP_REQUESTS_METRIC_URL_LABEL_ID = 0,
+  HTTP_REQUESTS_METRIC_RESPONSE_CODE_LABEL_ID,
+  HTTP_REQUESTS_METRIC_DRIVER_LABEL_ID,
+  HTTP_REQUESTS_METRIC_ID_LABEL_ID,
+
+  HTTP_REQUESTS_METRIC_LABELS_SIZE,
+};
+
 #define HTTP_HEADER_FORMAT_ERROR http_header_format_error_quark()
 
 static GQuark http_header_format_error_quark(void)
@@ -525,19 +535,19 @@ _curl_perform_request(HTTPDestinationWorker *self, const gchar *url)
             evt_tag_str("url", url));
 
   curl_easy_setopt(self->curl, CURLOPT_URL, url);
-  if (owner->message_compression != CURL_COMPRESSION_UNCOMPRESSED)
+  if (self->compressor)
     {
       if (compressor_compress(self->compressor, self->request_body_compressed, self->request_body))
         {
           curl_easy_setopt(self->curl, CURLOPT_POSTFIELDS, self->request_body_compressed->str);
           curl_easy_setopt(self->curl, CURLOPT_POSTFIELDSIZE, self->request_body_compressed->len);
+          _add_header(self->request_headers, "Content-Encoding", compressor_get_encoding_name(self->compressor));
         }
       else
         {
-          msg_warning("http-worker", evt_tag_error("Compression failed, sending uncompressed data."));
+          msg_warning("curl: error compressing data payload, sending uncompressed data instead");
           curl_easy_setopt(self->curl, CURLOPT_POSTFIELDS, self->request_body->str);
         }
-
     }
   else
     curl_easy_setopt(self->curl, CURLOPT_POSTFIELDS, self->request_body->str);
@@ -602,6 +612,28 @@ _map_http_status_code(HTTPDestinationWorker *self, const gchar *url, glong http_
   return default_map_http_status_to_worker_status(self, url, http_code);
 }
 
+static void
+_update_status_code_metrics(HTTPDestinationWorker *self, const gchar *url, glong http_code)
+{
+  gint level = log_pipe_is_internal(&self->super.owner->super.super.super) ? STATS_LEVEL3 : STATS_LEVEL1;
+
+  self->metrics.requests_labels[HTTP_REQUESTS_METRIC_URL_LABEL_ID].value = url;
+  g_snprintf(self->metrics.requests_response_code_str_buffer, sizeof(self->metrics.requests_response_code_str_buffer),
+             "%ld", http_code);
+
+  StatsClusterKey key;
+  stats_cluster_single_key_set(&key, "output_http_requests_total",
+                               self->metrics.requests_labels, HTTP_REQUESTS_METRIC_LABELS_SIZE);
+
+  StatsCounterItem *counter;
+
+  stats_lock();
+  StatsCluster *sc = stats_register_dynamic_counter(level, &key, SC_TYPE_SINGLE_VALUE, &counter);
+  stats_counter_inc(counter);
+  stats_unregister_dynamic_counter(sc, SC_TYPE_SINGLE_VALUE, &counter);
+  stats_unlock();
+}
+
 static LogThreadedResult
 _flush_on_target(HTTPDestinationWorker *self, const gchar *url)
 {
@@ -618,6 +650,8 @@ _flush_on_target(HTTPDestinationWorker *self, const gchar *url)
   if (debug_flag)
     _debug_response_info(self, url, http_code);
 
+  _update_status_code_metrics(self, url, http_code);
+
   HttpResponseReceivedSignalData signal_data =
   {
     .result = HTTP_SLOT_SUCCESS,
@@ -805,6 +839,17 @@ _insert_single(LogThreadedDestWorker *s, LogMessage *msg)
   return log_threaded_dest_worker_flush(&self->super, LTF_FLUSH_NORMAL);
 }
 
+static void
+_init_http_request_metrics(HTTPDestinationWorker *self)
+{
+  self->metrics.requests_labels[HTTP_REQUESTS_METRIC_URL_LABEL_ID] = stats_cluster_label("url", "");
+  self->metrics.requests_labels[HTTP_REQUESTS_METRIC_RESPONSE_CODE_LABEL_ID] = \
+      stats_cluster_label("response_code", self->metrics.requests_response_code_str_buffer);
+  self->metrics.requests_labels[HTTP_REQUESTS_METRIC_DRIVER_LABEL_ID] = stats_cluster_label("driver", "http");
+  self->metrics.requests_labels[HTTP_REQUESTS_METRIC_ID_LABEL_ID] = \
+      stats_cluster_label("id", self->super.owner->super.super.id);
+}
+
 static gboolean
 _init(LogThreadedDestWorker *s)
 {
@@ -817,22 +862,10 @@ _init(LogThreadedDestWorker *s)
     }
 
   self->request_body = g_string_sized_new(32768);
-  if (owner->message_compression != CURL_COMPRESSION_UNCOMPRESSED)
+  if (owner->content_compression != CURL_COMPRESSION_UNCOMPRESSED)
     {
       self->request_body_compressed = g_string_sized_new(32768);
-      switch (owner->message_compression)
-        {
-        case CURL_COMPRESSION_GZIP:
-          self->compressor = gzip_compressor_new();
-          break;
-        case CURL_COMPRESSION_DEFLATE:
-          self->compressor = deflate_compressor_new();
-          break;
-        default:
-          g_assert_not_reached();
-        }
-      gchar *buffer = g_strdup_printf("Content-Encoding: %s", curl_compression_types[owner->message_compression]);
-      owner->headers= g_list_append(owner->headers,  buffer);
+      self->compressor = construct_compressor_by_type(owner->content_compression);
     }
   self->request_headers = http_curl_header_list_new();
   if (!(self->curl = curl_easy_init()))
@@ -846,6 +879,7 @@ _init(LogThreadedDestWorker *s)
   _setup_static_options_in_curl(self);
   _reinit_request_headers(self);
   _reinit_request_body(self);
+  _init_http_request_metrics(self);
   return log_threaded_dest_worker_init_method(s);
 }
 
@@ -853,7 +887,6 @@ static void
 _deinit(LogThreadedDestWorker *s)
 {
   HTTPDestinationWorker *self = (HTTPDestinationWorker *) s;
-  HTTPDestinationDriver *owner = (HTTPDestinationDriver *) self->super.owner;
 
   if (self->url_buffer)
     g_string_free(self->url_buffer, TRUE);
@@ -862,7 +895,7 @@ _deinit(LogThreadedDestWorker *s)
   if (self->request_body_compressed)
     g_string_free(self->request_body_compressed, TRUE);
 
-  if (owner->message_compression != CURL_COMPRESSION_UNCOMPRESSED)
+  if (self->compressor)
     compressor_free(self->compressor);
   list_free(self->request_headers);
   curl_easy_cleanup(self->curl);
@@ -874,6 +907,7 @@ http_dw_free(LogThreadedDestWorker *s)
 {
   HTTPDestinationWorker *self = (HTTPDestinationWorker *) s;
 
+  g_free(self->metrics.requests_labels);
   http_lb_client_deinit(&self->lbc);
   log_threaded_dest_worker_free_method(s);
 }
@@ -895,6 +929,8 @@ http_dw_new(LogThreadedDestDriver *o, gint worker_index)
   else
     self->super.insert = _insert_single;
 
+  self->metrics.requests_labels = g_new0(StatsClusterLabel, HTTP_REQUESTS_METRIC_LABELS_SIZE);
+
   http_lb_client_init(&self->lbc, owner->load_balancer);
   return &self->super;
 }
