@@ -290,35 +290,28 @@ http_dd_set_accept_encoding(LogDriver *d, const gchar *encoding)
 
   if (self->accept_encoding != NULL)
     g_string_free(self->accept_encoding, TRUE);
-
+#if SYSLOG_NG_HTTP_COMPRESSION_ENABLED
   if (strcmp(encoding, CURL_COMPRESSION_LITERAL_ALL) == 0)
     self->accept_encoding = g_string_new("");
   else
     self->accept_encoding = g_string_new(encoding);
+#else
+  self->accept_encoding = NULL;
+  msg_warning("libcurl has been compiled without libZ support. Accept Encoding not supported",
+              evt_tag_str("encoding", encoding));
+#endif
 }
 
-void
-http_dd_set_message_compression(LogDriver *d, const gchar *encoding)
+gboolean
+http_dd_set_content_compression(LogDriver *d, const gchar *encoding)
 {
   HTTPDestinationDriver *self = (HTTPDestinationDriver *) d;
 
-  gboolean _encoding_valid = FALSE;
-  _encoding_valid = http_dd_check_curl_compression(encoding);
-  g_assert(_encoding_valid);
-
-  if (http_dd_curl_compression_string_match(encoding, CURL_COMPRESSION_UNCOMPRESSED))
-    {
-      self->message_compression = CURL_COMPRESSION_UNCOMPRESSED;
-      return;
-    }
-  else if (http_dd_curl_compression_string_match(encoding, CURL_COMPRESSION_GZIP))
-    self->message_compression = CURL_COMPRESSION_GZIP;
-  else if (http_dd_curl_compression_string_match(encoding, CURL_COMPRESSION_DEFLATE))
-    self->message_compression = CURL_COMPRESSION_DEFLATE;
-  else
-    self->message_compression = CURL_COMPRESSION_DEFAULT;
+  self->content_compression = compressor_lookup_type(encoding);
+  return self->content_compression != CURL_COMPRESSION_UNKNOWN;
 }
 
+
 void
 http_dd_set_peer_verify(LogDriver *d, gboolean verify)
 {
@@ -537,6 +530,7 @@ http_dd_new(GlobalConfig *cfg)
                                        SYSLOG_NG_VERSION, curl_info->version);
 
   self->response_handlers = http_response_handlers_new();
+  self->content_compression = CURL_COMPRESSION_DEFAULT;
 
   return &self->super.super.super;
 }
