@@ -69,7 +69,7 @@ extern int java_debug;
     JAVA_EMPTY = -2,
     JAVA_EOF = 0,                  /* "end of file"  */
     JAVA_error = 256,              /* error  */
-    JAVA_UNDEF = 10523,            /* "invalid token"  */
+    JAVA_UNDEF = 10531,            /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -90,7 +90,30 @@ extern int java_debug;
     LL_CONTEXT_SERVER_PROTO = 18,  /* LL_CONTEXT_SERVER_PROTO  */
     LL_CONTEXT_OPTIONS = 19,       /* LL_CONTEXT_OPTIONS  */
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
-    LL_CONTEXT_MAX = 21,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
+    LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
+    KW_ASSIGN = 9000,              /* KW_ASSIGN  */
+    KW_OR = 9001,                  /* KW_OR  */
+    KW_AND = 9002,                 /* KW_AND  */
+    KW_STR_EQ = 9003,              /* KW_STR_EQ  */
+    KW_STR_NE = 9004,              /* KW_STR_NE  */
+    KW_TA_EQ = 9005,               /* KW_TA_EQ  */
+    KW_TA_NE = 9006,               /* KW_TA_NE  */
+    KW_TAV_EQ = 9007,              /* KW_TAV_EQ  */
+    KW_TAV_NE = 9008,              /* KW_TAV_NE  */
+    KW_STR_LT = 9009,              /* KW_STR_LT  */
+    KW_STR_LE = 9010,              /* KW_STR_LE  */
+    KW_STR_GE = 9011,              /* KW_STR_GE  */
+    KW_STR_GT = 9012,              /* KW_STR_GT  */
+    KW_TA_LT = 9013,               /* KW_TA_LT  */
+    KW_TA_LE = 9014,               /* KW_TA_LE  */
+    KW_TA_GE = 9015,               /* KW_TA_GE  */
+    KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
+    KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
     KW_PARSER = 10002,             /* KW_PARSER  */
@@ -104,6 +127,7 @@ extern int java_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -132,6 +156,7 @@ extern int java_debug;
     KW_MAX_DYNAMIC = 10404,        /* KW_MAX_DYNAMIC  */
     KW_SYSLOG_STATS = 10405,       /* KW_SYSLOG_STATS  */
     KW_HEALTHCHECK_FREQ = 10406,   /* KW_HEALTHCHECK_FREQ  */
+    KW_WORKER_PARTITION_KEY = 10407, /* KW_WORKER_PARTITION_KEY  */
     KW_CHAIN_HOSTNAMES = 10090,    /* KW_CHAIN_HOSTNAMES  */
     KW_NORMALIZE_HOSTNAMES = 10091, /* KW_NORMALIZE_HOSTNAMES  */
     KW_KEEP_HOSTNAME = 10092,      /* KW_KEEP_HOSTNAME  */
@@ -179,6 +204,9 @@ extern int java_debug;
     KW_TIME_REOPEN = 10210,        /* KW_TIME_REOPEN  */
     KW_TIME_REAP = 10211,          /* KW_TIME_REAP  */
     KW_TIME_SLEEP = 10212,         /* KW_TIME_SLEEP  */
+    KW_PARTITIONS = 10213,         /* KW_PARTITIONS  */
+    KW_PARTITION_KEY = 10214,      /* KW_PARTITION_KEY  */
+    KW_PARALLELIZE = 10215,        /* KW_PARALLELIZE  */
     KW_TMPL_ESCAPE = 10220,        /* KW_TMPL_ESCAPE  */
     KW_OPTIONAL = 10230,           /* KW_OPTIONAL  */
     KW_CREATE_DIRS = 10240,        /* KW_CREATE_DIRS  */
@@ -225,6 +253,8 @@ extern int java_debug;
     LL_TOKEN = 10434,              /* LL_TOKEN  */
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
+    LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -238,13 +268,15 @@ extern int java_debug;
     KW_CAST = 10511,               /* KW_CAST  */
     KW_UPPER = 10512,              /* KW_UPPER  */
     KW_LOWER = 10513,              /* KW_LOWER  */
+    KW_INCLUDE_BYTES = 10514,      /* KW_INCLUDE_BYTES  */
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_JAVA = 10524,               /* KW_JAVA  */
-    KW_CLASS_PATH = 10525,         /* KW_CLASS_PATH  */
-    KW_CLASS_NAME = 10526,         /* KW_CLASS_NAME  */
-    KW_JVM_OPTIONS = 10527         /* KW_JVM_OPTIONS  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_JAVA = 10532,               /* KW_JAVA  */
+    KW_CLASS_PATH = 10533,         /* KW_CLASS_PATH  */
+    KW_CLASS_NAME = 10534,         /* KW_CLASS_NAME  */
+    KW_JVM_OPTIONS = 10535         /* KW_JVM_OPTIONS  */
   };
   typedef enum java_tokentype java_token_kind_t;
 #endif
@@ -252,7 +284,7 @@ extern int java_debug;
 #define JAVA_EMPTY -2
 #define JAVA_EOF 0
 #define JAVA_error 256
-#define JAVA_UNDEF 10523
+#define JAVA_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -273,7 +305,30 @@ extern int java_debug;
 #define LL_CONTEXT_SERVER_PROTO 18
 #define LL_CONTEXT_OPTIONS 19
 #define LL_CONTEXT_CONFIG 20
-#define LL_CONTEXT_MAX 21
+#define LL_CONTEXT_TEMPLATE_REF 21
+#define LL_CONTEXT_FILTERX 22
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
+#define KW_ASSIGN 9000
+#define KW_OR 9001
+#define KW_AND 9002
+#define KW_STR_EQ 9003
+#define KW_STR_NE 9004
+#define KW_TA_EQ 9005
+#define KW_TA_NE 9006
+#define KW_TAV_EQ 9007
+#define KW_TAV_NE 9008
+#define KW_STR_LT 9009
+#define KW_STR_LE 9010
+#define KW_STR_GE 9011
+#define KW_STR_GT 9012
+#define KW_TA_LT 9013
+#define KW_TA_LE 9014
+#define KW_TA_GE 9015
+#define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
+#define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
 #define KW_PARSER 10002
@@ -287,6 +342,7 @@ extern int java_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -315,6 +371,7 @@ extern int java_debug;
 #define KW_MAX_DYNAMIC 10404
 #define KW_SYSLOG_STATS 10405
 #define KW_HEALTHCHECK_FREQ 10406
+#define KW_WORKER_PARTITION_KEY 10407
 #define KW_CHAIN_HOSTNAMES 10090
 #define KW_NORMALIZE_HOSTNAMES 10091
 #define KW_KEEP_HOSTNAME 10092
@@ -362,6 +419,9 @@ extern int java_debug;
 #define KW_TIME_REOPEN 10210
 #define KW_TIME_REAP 10211
 #define KW_TIME_SLEEP 10212
+#define KW_PARTITIONS 10213
+#define KW_PARTITION_KEY 10214
+#define KW_PARALLELIZE 10215
 #define KW_TMPL_ESCAPE 10220
 #define KW_OPTIONAL 10230
 #define KW_CREATE_DIRS 10240
@@ -408,6 +468,8 @@ extern int java_debug;
 #define LL_TOKEN 10434
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
+#define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -421,13 +483,15 @@ extern int java_debug;
 #define KW_CAST 10511
 #define KW_UPPER 10512
 #define KW_LOWER 10513
+#define KW_INCLUDE_BYTES 10514
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_JAVA 10524
-#define KW_CLASS_PATH 10525
-#define KW_CLASS_NAME 10526
-#define KW_JVM_OPTIONS 10527
+#define KW_LABELS 10530
+#define KW_JAVA 10532
+#define KW_CLASS_PATH 10533
+#define KW_CLASS_NAME 10534
+#define KW_JVM_OPTIONS 10535
 
 /* Value type.  */
 #if ! defined JAVA_STYPE && ! defined JAVA_STYPE_IS_DECLARED
