@@ -69,7 +69,7 @@ extern int mqtt_debug;
     MQTT_EMPTY = -2,
     MQTT_EOF = 0,                  /* "end of file"  */
     MQTT_error = 256,              /* error  */
-    MQTT_UNDEF = 10523,            /* "invalid token"  */
+    MQTT_UNDEF = 10531,            /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -92,7 +92,9 @@ extern int mqtt_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -110,6 +112,7 @@ extern int mqtt_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -124,6 +127,7 @@ extern int mqtt_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -250,6 +254,7 @@ extern int mqtt_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -267,29 +272,30 @@ extern int mqtt_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_MQTT = 10524,               /* KW_MQTT  */
-    KW_TOPIC = 10525,              /* KW_TOPIC  */
-    KW_FALLBACK_TOPIC = 10526,     /* KW_FALLBACK_TOPIC  */
-    KW_KEEPALIVE = 10527,          /* KW_KEEPALIVE  */
-    KW_ADDRESS = 10528,            /* KW_ADDRESS  */
-    KW_QOS = 10529,                /* KW_QOS  */
-    KW_CLIENT_ID = 10530,          /* KW_CLIENT_ID  */
-    KW_CLEANSESSION = 10531,       /* KW_CLEANSESSION  */
-    KW_MESSAGE_TEMPLATE = 10532,   /* KW_MESSAGE_TEMPLATE  */
-    KW_USERNAME = 10533,           /* KW_USERNAME  */
-    KW_PASSWORD = 10534,           /* KW_PASSWORD  */
-    KW_HTTP_PROXY = 10535,         /* KW_HTTP_PROXY  */
-    KW_TLS = 10536,                /* KW_TLS  */
-    KW_CA_DIR = 10537,             /* KW_CA_DIR  */
-    KW_CA_FILE = 10538,            /* KW_CA_FILE  */
-    KW_CERT_FILE = 10539,          /* KW_CERT_FILE  */
-    KW_KEY_FILE = 10540,           /* KW_KEY_FILE  */
-    KW_CIPHER_SUITE = 10541,       /* KW_CIPHER_SUITE  */
-    KW_TLS12_AND_OLDER = 10542,    /* KW_TLS12_AND_OLDER  */
-    KW_TLS13 = 10543,              /* KW_TLS13  */
-    KW_USE_SYSTEM_CERT_STORE = 10544, /* KW_USE_SYSTEM_CERT_STORE  */
-    KW_SSL_VERSION = 10545,        /* KW_SSL_VERSION  */
-    KW_PEER_VERIFY = 10546         /* KW_PEER_VERIFY  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_MQTT = 10532,               /* KW_MQTT  */
+    KW_TOPIC = 10533,              /* KW_TOPIC  */
+    KW_FALLBACK_TOPIC = 10534,     /* KW_FALLBACK_TOPIC  */
+    KW_KEEPALIVE = 10535,          /* KW_KEEPALIVE  */
+    KW_ADDRESS = 10536,            /* KW_ADDRESS  */
+    KW_QOS = 10537,                /* KW_QOS  */
+    KW_CLIENT_ID = 10538,          /* KW_CLIENT_ID  */
+    KW_CLEANSESSION = 10539,       /* KW_CLEANSESSION  */
+    KW_MESSAGE_TEMPLATE = 10540,   /* KW_MESSAGE_TEMPLATE  */
+    KW_USERNAME = 10541,           /* KW_USERNAME  */
+    KW_PASSWORD = 10542,           /* KW_PASSWORD  */
+    KW_HTTP_PROXY = 10543,         /* KW_HTTP_PROXY  */
+    KW_TLS = 10544,                /* KW_TLS  */
+    KW_CA_DIR = 10545,             /* KW_CA_DIR  */
+    KW_CA_FILE = 10546,            /* KW_CA_FILE  */
+    KW_CERT_FILE = 10547,          /* KW_CERT_FILE  */
+    KW_KEY_FILE = 10548,           /* KW_KEY_FILE  */
+    KW_CIPHER_SUITE = 10549,       /* KW_CIPHER_SUITE  */
+    KW_TLS12_AND_OLDER = 10550,    /* KW_TLS12_AND_OLDER  */
+    KW_TLS13 = 10551,              /* KW_TLS13  */
+    KW_USE_SYSTEM_CERT_STORE = 10552, /* KW_USE_SYSTEM_CERT_STORE  */
+    KW_SSL_VERSION = 10553,        /* KW_SSL_VERSION  */
+    KW_PEER_VERIFY = 10554         /* KW_PEER_VERIFY  */
   };
   typedef enum mqtt_tokentype mqtt_token_kind_t;
 #endif
@@ -297,7 +303,7 @@ extern int mqtt_debug;
 #define MQTT_EMPTY -2
 #define MQTT_EOF 0
 #define MQTT_error 256
-#define MQTT_UNDEF 10523
+#define MQTT_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -320,7 +326,9 @@ extern int mqtt_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -338,6 +346,7 @@ extern int mqtt_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -352,6 +361,7 @@ extern int mqtt_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -478,6 +488,7 @@ extern int mqtt_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -495,29 +506,30 @@ extern int mqtt_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_MQTT 10524
-#define KW_TOPIC 10525
-#define KW_FALLBACK_TOPIC 10526
-#define KW_KEEPALIVE 10527
-#define KW_ADDRESS 10528
-#define KW_QOS 10529
-#define KW_CLIENT_ID 10530
-#define KW_CLEANSESSION 10531
-#define KW_MESSAGE_TEMPLATE 10532
-#define KW_USERNAME 10533
-#define KW_PASSWORD 10534
-#define KW_HTTP_PROXY 10535
-#define KW_TLS 10536
-#define KW_CA_DIR 10537
-#define KW_CA_FILE 10538
-#define KW_CERT_FILE 10539
-#define KW_KEY_FILE 10540
-#define KW_CIPHER_SUITE 10541
-#define KW_TLS12_AND_OLDER 10542
-#define KW_TLS13 10543
-#define KW_USE_SYSTEM_CERT_STORE 10544
-#define KW_SSL_VERSION 10545
-#define KW_PEER_VERIFY 10546
+#define KW_LABELS 10530
+#define KW_MQTT 10532
+#define KW_TOPIC 10533
+#define KW_FALLBACK_TOPIC 10534
+#define KW_KEEPALIVE 10535
+#define KW_ADDRESS 10536
+#define KW_QOS 10537
+#define KW_CLIENT_ID 10538
+#define KW_CLEANSESSION 10539
+#define KW_MESSAGE_TEMPLATE 10540
+#define KW_USERNAME 10541
+#define KW_PASSWORD 10542
+#define KW_HTTP_PROXY 10543
+#define KW_TLS 10544
+#define KW_CA_DIR 10545
+#define KW_CA_FILE 10546
+#define KW_CERT_FILE 10547
+#define KW_KEY_FILE 10548
+#define KW_CIPHER_SUITE 10549
+#define KW_TLS12_AND_OLDER 10550
+#define KW_TLS13 10551
+#define KW_USE_SYSTEM_CERT_STORE 10552
+#define KW_SSL_VERSION 10553
+#define KW_PEER_VERIFY 10554
 
 /* Value type.  */
 #if ! defined MQTT_STYPE && ! defined MQTT_STYPE_IS_DECLARED
