@@ -69,7 +69,7 @@ extern int timestamp_debug;
     TIMESTAMP_EMPTY = -2,
     TIMESTAMP_EOF = 0,             /* "end of file"  */
     TIMESTAMP_error = 256,         /* error  */
-    TIMESTAMP_UNDEF = 10523,       /* "invalid token"  */
+    TIMESTAMP_UNDEF = 10531,       /* "invalid token"  */
     LL_CONTEXT_ROOT = 1,           /* LL_CONTEXT_ROOT  */
     LL_CONTEXT_DESTINATION = 2,    /* LL_CONTEXT_DESTINATION  */
     LL_CONTEXT_SOURCE = 3,         /* LL_CONTEXT_SOURCE  */
@@ -92,7 +92,9 @@ extern int timestamp_debug;
     LL_CONTEXT_CONFIG = 20,        /* LL_CONTEXT_CONFIG  */
     LL_CONTEXT_TEMPLATE_REF = 21,  /* LL_CONTEXT_TEMPLATE_REF  */
     LL_CONTEXT_FILTERX = 22,       /* LL_CONTEXT_FILTERX  */
-    LL_CONTEXT_MAX = 23,           /* LL_CONTEXT_MAX  */
+    LL_CONTEXT_FILTERX_FUNC = 23,  /* LL_CONTEXT_FILTERX_FUNC  */
+    LL_CONTEXT_FILTERX_ENUM = 24,  /* LL_CONTEXT_FILTERX_ENUM  */
+    LL_CONTEXT_MAX = 25,           /* LL_CONTEXT_MAX  */
     KW_ASSIGN = 9000,              /* KW_ASSIGN  */
     KW_OR = 9001,                  /* KW_OR  */
     KW_AND = 9002,                 /* KW_AND  */
@@ -110,6 +112,7 @@ extern int timestamp_debug;
     KW_TA_LE = 9014,               /* KW_TA_LE  */
     KW_TA_GE = 9015,               /* KW_TA_GE  */
     KW_TA_GT = 9016,               /* KW_TA_GT  */
+    KW_PLUS_ASSIGN = 9018,         /* KW_PLUS_ASSIGN  */
     KW_NOT = 9017,                 /* KW_NOT  */
     KW_SOURCE = 10000,             /* KW_SOURCE  */
     KW_FILTER = 10001,             /* KW_FILTER  */
@@ -124,6 +127,7 @@ extern int timestamp_debug;
     KW_IF = 10010,                 /* KW_IF  */
     KW_ELSE = 10011,               /* KW_ELSE  */
     KW_ELIF = 10012,               /* KW_ELIF  */
+    KW_FILTERX = 10013,            /* KW_FILTERX  */
     KW_INTERNAL = 10020,           /* KW_INTERNAL  */
     KW_SYSLOG = 10060,             /* KW_SYSLOG  */
     KW_MARK_FREQ = 10071,          /* KW_MARK_FREQ  */
@@ -250,6 +254,7 @@ extern int timestamp_debug;
     LL_BLOCK = 10435,              /* LL_BLOCK  */
     LL_PLUGIN = 10436,             /* LL_PLUGIN  */
     LL_TEMPLATE_REF = 10437,       /* LL_TEMPLATE_REF  */
+    LL_MESSAGE_REF = 10438,        /* LL_MESSAGE_REF  */
     KW_VALUE_PAIRS = 10500,        /* KW_VALUE_PAIRS  */
     KW_EXCLUDE = 10502,            /* KW_EXCLUDE  */
     KW_PAIR = 10503,               /* KW_PAIR  */
@@ -267,11 +272,12 @@ extern int timestamp_debug;
     KW_ON_ERROR = 10520,           /* KW_ON_ERROR  */
     KW_RETRIES = 10521,            /* KW_RETRIES  */
     KW_FETCH_NO_DATA_DELAY = 10522, /* KW_FETCH_NO_DATA_DELAY  */
-    KW_DATE_PARSER = 10524,        /* KW_DATE_PARSER  */
-    KW_TIME_STAMP = 10525,         /* KW_TIME_STAMP  */
-    KW_FIX_TIME_ZONE = 10526,      /* KW_FIX_TIME_ZONE  */
-    KW_SET_TIME_ZONE = 10527,      /* KW_SET_TIME_ZONE  */
-    KW_GUESS_TIME_ZONE = 10528     /* KW_GUESS_TIME_ZONE  */
+    KW_LABELS = 10530,             /* KW_LABELS  */
+    KW_DATE_PARSER = 10532,        /* KW_DATE_PARSER  */
+    KW_TIME_STAMP = 10533,         /* KW_TIME_STAMP  */
+    KW_FIX_TIME_ZONE = 10534,      /* KW_FIX_TIME_ZONE  */
+    KW_SET_TIME_ZONE = 10535,      /* KW_SET_TIME_ZONE  */
+    KW_GUESS_TIME_ZONE = 10536     /* KW_GUESS_TIME_ZONE  */
   };
   typedef enum timestamp_tokentype timestamp_token_kind_t;
 #endif
@@ -279,7 +285,7 @@ extern int timestamp_debug;
 #define TIMESTAMP_EMPTY -2
 #define TIMESTAMP_EOF 0
 #define TIMESTAMP_error 256
-#define TIMESTAMP_UNDEF 10523
+#define TIMESTAMP_UNDEF 10531
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -302,7 +308,9 @@ extern int timestamp_debug;
 #define LL_CONTEXT_CONFIG 20
 #define LL_CONTEXT_TEMPLATE_REF 21
 #define LL_CONTEXT_FILTERX 22
-#define LL_CONTEXT_MAX 23
+#define LL_CONTEXT_FILTERX_FUNC 23
+#define LL_CONTEXT_FILTERX_ENUM 24
+#define LL_CONTEXT_MAX 25
 #define KW_ASSIGN 9000
 #define KW_OR 9001
 #define KW_AND 9002
@@ -320,6 +328,7 @@ extern int timestamp_debug;
 #define KW_TA_LE 9014
 #define KW_TA_GE 9015
 #define KW_TA_GT 9016
+#define KW_PLUS_ASSIGN 9018
 #define KW_NOT 9017
 #define KW_SOURCE 10000
 #define KW_FILTER 10001
@@ -334,6 +343,7 @@ extern int timestamp_debug;
 #define KW_IF 10010
 #define KW_ELSE 10011
 #define KW_ELIF 10012
+#define KW_FILTERX 10013
 #define KW_INTERNAL 10020
 #define KW_SYSLOG 10060
 #define KW_MARK_FREQ 10071
@@ -460,6 +470,7 @@ extern int timestamp_debug;
 #define LL_BLOCK 10435
 #define LL_PLUGIN 10436
 #define LL_TEMPLATE_REF 10437
+#define LL_MESSAGE_REF 10438
 #define KW_VALUE_PAIRS 10500
 #define KW_EXCLUDE 10502
 #define KW_PAIR 10503
@@ -477,11 +488,12 @@ extern int timestamp_debug;
 #define KW_ON_ERROR 10520
 #define KW_RETRIES 10521
 #define KW_FETCH_NO_DATA_DELAY 10522
-#define KW_DATE_PARSER 10524
-#define KW_TIME_STAMP 10525
-#define KW_FIX_TIME_ZONE 10526
-#define KW_SET_TIME_ZONE 10527
-#define KW_GUESS_TIME_ZONE 10528
+#define KW_LABELS 10530
+#define KW_DATE_PARSER 10532
+#define KW_TIME_STAMP 10533
+#define KW_FIX_TIME_ZONE 10534
+#define KW_SET_TIME_ZONE 10535
+#define KW_GUESS_TIME_ZONE 10536
 
 /* Value type.  */
 #if ! defined TIMESTAMP_STYPE && ! defined TIMESTAMP_STYPE_IS_DECLARED
